Method: PulpcoreClient::AccessPoliciesApi#list

Defined in:
lib/pulpcore_client/api/access_policies_api.rb

#list(opts = {}) ⇒ PaginatedAccessPolicyResponseList

List access policys ViewSet for AccessPolicy.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :customized (Boolean)

    Filter results where customized matches value

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;creation_hooks&#x60; - Creation hooks * &#x60;-creation_hooks&#x60; - Creation hooks (descending) * &#x60;statements&#x60; - Statements * &#x60;-statements&#x60; - Statements (descending) * &#x60;viewset_name&#x60; - Viewset name * &#x60;-viewset_name&#x60; - Viewset name (descending) * &#x60;customized&#x60; - Customized * &#x60;-customized&#x60; - Customized (descending) * &#x60;queryset_scoping&#x60; - Queryset scoping * &#x60;-queryset_scoping&#x60; - Queryset scoping (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending)

  • :prn__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :q (String)

    Filter results by using NOT, AND and OR operations on other filters

  • :viewset_name (String)

    Filter results where viewset_name matches value

  • :viewset_name__contains (String)

    Filter results where viewset_name contains value

  • :viewset_name__icontains (String)

    Filter results where viewset_name contains value

  • :viewset_name__iexact (String)

    Filter results where viewset_name matches value

  • :viewset_name__in (Array<String>)

    Filter results where viewset_name is in a comma-separated list of values

  • :viewset_name__iregex (String)

    Filter results where viewset_name matches regex value

  • :viewset_name__istartswith (String)

    Filter results where viewset_name starts with value

  • :viewset_name__regex (String)

    Filter results where viewset_name matches regex value

  • :viewset_name__startswith (String)

    Filter results where viewset_name starts with value

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



45
46
47
48
# File 'lib/pulpcore_client/api/access_policies_api.rb', line 45

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end