Method: PulpcoreClient::AccessPoliciesApi#read

Defined in:
lib/pulpcore_client/api/access_policies_api.rb

#read(access_policy_href, opts = {}) ⇒ AccessPolicyResponse

Inspect an access policy ViewSet for AccessPolicy.

Parameters:

  • access_policy_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



221
222
223
224
# File 'lib/pulpcore_client/api/access_policies_api.rb', line 221

def read(access_policy_href, opts = {})
  data, _status_code, _headers = read_with_http_info(access_policy_href, opts)
  data
end