Method: PulpcoreClient::ContentOpenpgpPublickeyApi#create

Defined in:
lib/pulpcore_client/api/content_openpgp_publickey_api.rb

#create(opts = {}) ⇒ AsyncOperationResponse

Create an open pgp public key Trigger an asynchronous task to create content,optionally create new repository version.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :repository (String)

    A URI of a repository the new content unit should be associated with.

  • :pulp_labels (Hash<String, String>)

    A dictionary of arbitrary key/value pairs used to describe a specific Content instance.

  • :file (File)

    An uploaded file that may be turned into the content unit.

  • :upload (String)

    An uncommitted upload that may be turned into the content unit.

  • :file_url (String)

    A url that Pulp can download and turn into the content unit.

Returns:



31
32
33
34
# File 'lib/pulpcore_client/api/content_openpgp_publickey_api.rb', line 31

def create(opts = {})
  data, _status_code, _headers = create_with_http_info(opts)
  data
end