Method: PulpcoreClient::ContentOpenpgpPublickeyApi#create_with_http_info

Defined in:
lib/pulpcore_client/api/content_openpgp_publickey_api.rb

#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Create an open pgp public key Trigger an asynchronous task to create content,optionally create new repository version.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :repository (String)

    A URI of a repository the new content unit should be associated with.

  • :pulp_labels (Hash<String, String>)

    A dictionary of arbitrary key/value pairs used to describe a specific Content instance.

  • :file (File)

    An uploaded file that may be turned into the content unit.

  • :upload (String)

    An uncommitted upload that may be turned into the content unit.

  • :file_url (String)

    A url that Pulp can download and turn into the content unit.

Returns:

  • (Array<(AsyncOperationResponse, Integer, Hash)>)

    AsyncOperationResponse data, response status code and response headers



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/pulpcore_client/api/content_openpgp_publickey_api.rb', line 45

def create_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContentOpenpgpPublickeyApi.create ...'
  end
  if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1
    fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentOpenpgpPublickeyApi.create, the character length must be great than or equal to 1.'
  end

  # resource path
  local_var_path = '/pulp/api/v3/content/core/openpgp_publickey/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil?
  form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil?
  form_params['file'] = opts[:'file'] if !opts[:'file'].nil?
  form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil?
  form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AsyncOperationResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth']

  new_options = opts.merge(
    :operation => :"ContentOpenpgpPublickeyApi.create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContentOpenpgpPublickeyApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end