Method: PulpcoreClient::ContentOpenpgpPublickeyApi#list
- Defined in:
- lib/pulpcore_client/api/content_openpgp_publickey_api.rb
#list(opts = {}) ⇒ PaginatedOpenPGPPublicKeyResponseList
List open pgp public keys A ViewSet for uploads that do not require to store an uploaded content as an Artifact.
Parameters:
-
opts
(Hash)
(defaults to: {})
—
the optional parameters
Options Hash (opts):
-
:fingerprint
(String)
—
Filter results where fingerprint matches value
-
:limit
(Integer)
—
Number of results to return per page.
-
:offset
(Integer)
—
The initial index from which to return the results.
-
:ordering
(Array<String>)
—
Ordering * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)
-
:orphaned_for
(Float)
—
Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
-
:prn__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_href__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_id__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_label_select
(String)
—
Filter labels by search string
-
:q
(String)
—
Filter results by using NOT, AND and OR operations on other filters
-
:repository_version
(String)
—
Repository Version referenced by HREF/PRN
-
:repository_version_added
(String)
—
Repository Version referenced by HREF/PRN
-
:repository_version_removed
(String)
—
Repository Version referenced by HREF/PRN
-
:fields
(Array<String>)
—
A list of fields to include in the response.
-
:exclude_fields
(Array<String>)
—
A list of fields to exclude from the response.
Returns:
122 123 124 125 |
# File 'lib/pulpcore_client/api/content_openpgp_publickey_api.rb', line 122 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |