Method: PulpcoreClient::ContentOpenpgpPublickeyApi#read

Defined in:
lib/pulpcore_client/api/content_openpgp_publickey_api.rb

#read(open_p_g_p_public_key_href, opts = {}) ⇒ OpenPGPPublicKeyResponse

Inspect an open pgp public key A ViewSet for uploads that do not require to store an uploaded content as an Artifact.

Parameters:

  • open_p_g_p_public_key_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



216
217
218
219
# File 'lib/pulpcore_client/api/content_openpgp_publickey_api.rb', line 216

def read(open_p_g_p_public_key_href, opts = {})
  data, _status_code, _headers = read_with_http_info(open_p_g_p_public_key_href, opts)
  data
end