Method: PulpcoreClient::DistributionsOpenpgpApi#read

Defined in:
lib/pulpcore_client/api/distributions_openpgp_api.rb

#read(open_p_g_p_distribution_href, opts = {}) ⇒ OpenPGPDistributionResponse

Inspect an open pgp distribution Provides read and list methods and also provides asynchronous CUD methods to dispatch tasks with reservation that lock all Distributions preventing race conditions during base_path checking.

Parameters:

  • open_p_g_p_distribution_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



331
332
333
334
# File 'lib/pulpcore_client/api/distributions_openpgp_api.rb', line 331

def read(open_p_g_p_distribution_href, opts = {})
  data, _status_code, _headers = read_with_http_info(open_p_g_p_distribution_href, opts)
  data
end