Method: PulpcoreClient::NestedOpenPGPUserIDResponse#initialize
- Defined in:
- lib/pulpcore_client/models/nested_open_pgp_user_id_response.rb
#initialize(attributes = {}) ⇒ NestedOpenPGPUserIDResponse
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/pulpcore_client/models/nested_open_pgp_user_id_response.rb', line 52 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::NestedOpenPGPUserIDResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::NestedOpenPGPUserIDResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'signatures') if (value = attributes[:'signatures']).is_a?(Array) self.signatures = value end end end |