Method: PulpcoreClient::PatchedOpenPGPDistribution#list_invalid_properties

Defined in:
lib/pulpcore_client/models/patched_open_pgp_distribution.rb

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/pulpcore_client/models/patched_open_pgp_distribution.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@base_path.nil? && @base_path.to_s.length < 1
    invalid_properties.push('invalid value for "base_path", the character length must be great than or equal to 1.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  invalid_properties
end