Method: PulpcoreClient::UserGroup#list_invalid_properties

Defined in:
lib/pulpcore_client/models/user_group.rb

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/pulpcore_client/models/user_group.rb', line 71

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 150
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 150.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  invalid_properties
end