Class: PulpcoreClient::ArtifactDistributionResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/models/artifact_distribution_response.rb

Overview

A serializer for ArtifactDistribution.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ArtifactDistributionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::ArtifactDistributionResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::ArtifactDistributionResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hidden')
    self.hidden = attributes[:'hidden']
  else
    self.hidden = false
  end

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'no_content_change_since')
    self.no_content_change_since = attributes[:'no_content_change_since']
  end

  if attributes.key?(:'repository_version')
    self.repository_version = attributes[:'repository_version']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'pulp_href')
    self.pulp_href = attributes[:'pulp_href']
  end

  if attributes.key?(:'prn')
    self.prn = attributes[:'prn']
  end

  if attributes.key?(:'content_guard_prn')
    self.content_guard_prn = attributes[:'content_guard_prn']
  end

  if attributes.key?(:'content_guard')
    self.content_guard = attributes[:'content_guard']
  end

  if attributes.key?(:'pulp_created')
    self.pulp_created = attributes[:'pulp_created']
  end

  if attributes.key?(:'base_path')
    self.base_path = attributes[:'base_path']
  else
    self.base_path = nil
  end

  if attributes.key?(:'pulp_last_updated')
    self.pulp_last_updated = attributes[:'pulp_last_updated']
  end
end

Instance Attribute Details

#base_pathObject

The base (relative) path component of the published url. Avoid paths that overlap with other distribution base paths (e.g. \“foo\” and \“foo/bar\”)



51
52
53
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 51

def base_path
  @base_path
end

#base_urlObject

The URL for accessing the publication as defined by this distribution.



23
24
25
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 23

def base_url
  @base_url
end

#content_guardObject

An optional content-guard.



45
46
47
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 45

def content_guard
  @content_guard
end

#content_guard_prnObject

The Pulp Resource Name (PRN) of the associated optional content guard.



42
43
44
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 42

def content_guard_prn
  @content_guard_prn
end

#hiddenObject

Whether this distribution should be shown in the content app.



20
21
22
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 20

def hidden
  @hidden
end

#nameObject

A unique name. Ex, rawhide and stable.



34
35
36
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 34

def name
  @name
end

#no_content_change_sinceObject

Timestamp since when the distributed content served by this distribution has not changed. If equals to null, no guarantee is provided about content changes.



28
29
30
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 28

def no_content_change_since
  @no_content_change_since
end

#prnObject

The Pulp Resource Name (PRN).



39
40
41
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 39

def prn
  @prn
end

#pulp_createdObject

Timestamp of creation.



48
49
50
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 48

def pulp_created
  @pulp_created
end

#pulp_hrefObject

Returns the value of attribute pulp_href.



36
37
38
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 36

def pulp_href
  @pulp_href
end

#pulp_labelsObject

Returns the value of attribute pulp_labels.



25
26
27
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 25

def pulp_labels
  @pulp_labels
end

#pulp_last_updatedObject

Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.



54
55
56
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 54

def pulp_last_updated
  @pulp_last_updated
end

#repository_versionObject

RepositoryVersion to be served



31
32
33
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 31

def repository_version
  @repository_version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 267

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpcoreClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 76

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 57

def self.attribute_map
  {
    :'hidden' => :'hidden',
    :'base_url' => :'base_url',
    :'pulp_labels' => :'pulp_labels',
    :'no_content_change_since' => :'no_content_change_since',
    :'repository_version' => :'repository_version',
    :'name' => :'name',
    :'pulp_href' => :'pulp_href',
    :'prn' => :'prn',
    :'content_guard_prn' => :'content_guard_prn',
    :'content_guard' => :'content_guard',
    :'pulp_created' => :'pulp_created',
    :'base_path' => :'base_path',
    :'pulp_last_updated' => :'pulp_last_updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 100

def self.openapi_nullable
  Set.new([
    :'repository_version',
    :'content_guard',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 81

def self.openapi_types
  {
    :'hidden' => :'Boolean',
    :'base_url' => :'String',
    :'pulp_labels' => :'Hash<String, String>',
    :'no_content_change_since' => :'String',
    :'repository_version' => :'String',
    :'name' => :'String',
    :'pulp_href' => :'String',
    :'prn' => :'String',
    :'content_guard_prn' => :'String',
    :'content_guard' => :'String',
    :'pulp_created' => :'Time',
    :'base_path' => :'String',
    :'pulp_last_updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hidden == o.hidden &&
      base_url == o.base_url &&
      pulp_labels == o.pulp_labels &&
      no_content_change_since == o.no_content_change_since &&
      repository_version == o.repository_version &&
      name == o.name &&
      pulp_href == o.pulp_href &&
      prn == o.prn &&
      content_guard_prn == o.content_guard_prn &&
      content_guard == o.content_guard &&
      pulp_created == o.pulp_created &&
      base_path == o.base_path &&
      pulp_last_updated == o.pulp_last_updated
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 338

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 236

def hash
  [hidden, base_url, pulp_labels, no_content_change_since, repository_version, name, pulp_href, prn, content_guard_prn, content_guard, pulp_created, base_path, pulp_last_updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @base_path.nil?
    invalid_properties.push('invalid value for "base_path", base_path cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 314

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



308
309
310
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 308

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
# File 'lib/pulpcore_client/models/artifact_distribution_response.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @base_path.nil?
  true
end