Class: PulpcoreClient::ContentguardsHeaderApi
- Inherits:
-
Object
- Object
- PulpcoreClient::ContentguardsHeaderApi
- Defined in:
- lib/pulpcore_client/api/contentguards_header_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_role(header_content_guard_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
-
#add_role_with_http_info(header_content_guard_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
-
#create(header_content_guard, opts = {}) ⇒ HeaderContentGuardResponse
Create a header content guard Content guard to protect the content app using a specific header.
-
#create_with_http_info(header_content_guard, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Create a header content guard Content guard to protect the content app using a specific header.
-
#delete(header_content_guard_href, opts = {}) ⇒ nil
Delete a header content guard Content guard to protect the content app using a specific header.
-
#delete_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a header content guard Content guard to protect the content app using a specific header.
-
#initialize(api_client = ApiClient.default) ⇒ ContentguardsHeaderApi
constructor
A new instance of ContentguardsHeaderApi.
-
#list(opts = {}) ⇒ PaginatedHeaderContentGuardResponseList
List header content guards Content guard to protect the content app using a specific header.
-
#list_roles(header_content_guard_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
-
#list_roles_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedHeaderContentGuardResponseList, Integer, Hash)>
List header content guards Content guard to protect the content app using a specific header.
-
#my_permissions(header_content_guard_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
-
#my_permissions_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
-
#partial_update(header_content_guard_href, patched_header_content_guard, opts = {}) ⇒ HeaderContentGuardResponse
Update a header content guard Content guard to protect the content app using a specific header.
-
#partial_update_with_http_info(header_content_guard_href, patched_header_content_guard, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Update a header content guard Content guard to protect the content app using a specific header.
-
#read(header_content_guard_href, opts = {}) ⇒ HeaderContentGuardResponse
Inspect a header content guard Content guard to protect the content app using a specific header.
-
#read_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Inspect a header content guard Content guard to protect the content app using a specific header.
-
#remove_role(header_content_guard_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
-
#remove_role_with_http_info(header_content_guard_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
-
#update(header_content_guard_href, header_content_guard, opts = {}) ⇒ HeaderContentGuardResponse
Update a header content guard Content guard to protect the content app using a specific header.
-
#update_with_http_info(header_content_guard_href, header_content_guard, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Update a header content guard Content guard to protect the content app using a specific header.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentguardsHeaderApi
Returns a new instance of ContentguardsHeaderApi.
19 20 21 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_role(header_content_guard_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
29 30 31 32 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 29 def add_role(header_content_guard_href, nested_role, opts = {}) data, _status_code, _headers = add_role_with_http_info(header_content_guard_href, nested_role, opts) data end |
#add_role_with_http_info(header_content_guard_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 41 def add_role_with_http_info(header_content_guard_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.add_role ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.add_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling ContentguardsHeaderApi.add_role" end # resource path local_var_path = '{header_content_guard_href}add_role/'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(header_content_guard, opts = {}) ⇒ HeaderContentGuardResponse
Create a header content guard Content guard to protect the content app using a specific header.
101 102 103 104 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 101 def create(header_content_guard, opts = {}) data, _status_code, _headers = create_with_http_info(header_content_guard, opts) data end |
#create_with_http_info(header_content_guard, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Create a header content guard Content guard to protect the content app using a specific header.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 112 def create_with_http_info(header_content_guard, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.create ...' end # verify the required parameter 'header_content_guard' is set if @api_client.config.client_side_validation && header_content_guard.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard' when calling ContentguardsHeaderApi.create" end # resource path local_var_path = '/pulp/api/v3/contentguards/core/header/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(header_content_guard) # return_type return_type = opts[:return_type] || 'HeaderContentGuardResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(header_content_guard_href, opts = {}) ⇒ nil
Delete a header content guard Content guard to protect the content app using a specific header.
168 169 170 171 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 168 def delete(header_content_guard_href, opts = {}) delete_with_http_info(header_content_guard_href, opts) nil end |
#delete_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a header content guard Content guard to protect the content app using a specific header.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 179 def delete_with_http_info(header_content_guard_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.delete ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.delete" end # resource path local_var_path = '{header_content_guard_href}'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedHeaderContentGuardResponseList
List header content guards Content guard to protect the content app using a specific header.
247 248 249 250 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 247 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_roles(header_content_guard_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
347 348 349 350 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 347 def list_roles(header_content_guard_href, opts = {}) data, _status_code, _headers = list_roles_with_http_info(header_content_guard_href, opts) data end |
#list_roles_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 360 def list_roles_with_http_info(header_content_guard_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.list_roles ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.list_roles" end # resource path local_var_path = '{header_content_guard_href}list_roles/'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'ObjectRolesResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedHeaderContentGuardResponseList, Integer, Hash)>
List header content guards Content guard to protect the content app using a specific header.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 274 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.list ...' end allowable_values = ["-description", "-name", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-pulp_type", "description", "name", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "pulp_type"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/contentguards/core/header/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__iregex'] = opts[:'name__iregex'] if !opts[:'name__iregex'].nil? query_params[:'name__istartswith'] = opts[:'name__istartswith'] if !opts[:'name__istartswith'].nil? query_params[:'name__regex'] = opts[:'name__regex'] if !opts[:'name__regex'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginatedHeaderContentGuardResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#my_permissions(header_content_guard_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
418 419 420 421 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 418 def (header_content_guard_href, opts = {}) data, _status_code, _headers = (header_content_guard_href, opts) data end |
#my_permissions_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 431 def (header_content_guard_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.my_permissions ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.my_permissions" end # resource path local_var_path = '{header_content_guard_href}my_permissions/'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MyPermissionsResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(header_content_guard_href, patched_header_content_guard, opts = {}) ⇒ HeaderContentGuardResponse
Update a header content guard Content guard to protect the content app using a specific header.
488 489 490 491 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 488 def partial_update(header_content_guard_href, patched_header_content_guard, opts = {}) data, _status_code, _headers = partial_update_with_http_info(header_content_guard_href, patched_header_content_guard, opts) data end |
#partial_update_with_http_info(header_content_guard_href, patched_header_content_guard, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Update a header content guard Content guard to protect the content app using a specific header.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 500 def partial_update_with_http_info(header_content_guard_href, patched_header_content_guard, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.partial_update ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.partial_update" end # verify the required parameter 'patched_header_content_guard' is set if @api_client.config.client_side_validation && patched_header_content_guard.nil? fail ArgumentError, "Missing the required parameter 'patched_header_content_guard' when calling ContentguardsHeaderApi.partial_update" end # resource path local_var_path = '{header_content_guard_href}'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(patched_header_content_guard) # return_type return_type = opts[:return_type] || 'HeaderContentGuardResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(header_content_guard_href, opts = {}) ⇒ HeaderContentGuardResponse
Inspect a header content guard Content guard to protect the content app using a specific header.
562 563 564 565 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 562 def read(header_content_guard_href, opts = {}) data, _status_code, _headers = read_with_http_info(header_content_guard_href, opts) data end |
#read_with_http_info(header_content_guard_href, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Inspect a header content guard Content guard to protect the content app using a specific header.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 575 def read_with_http_info(header_content_guard_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.read ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.read" end # resource path local_var_path = '{header_content_guard_href}'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'HeaderContentGuardResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_role(header_content_guard_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
632 633 634 635 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 632 def remove_role(header_content_guard_href, nested_role, opts = {}) data, _status_code, _headers = remove_role_with_http_info(header_content_guard_href, nested_role, opts) data end |
#remove_role_with_http_info(header_content_guard_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 644 def remove_role_with_http_info(header_content_guard_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.remove_role ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.remove_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling ContentguardsHeaderApi.remove_role" end # resource path local_var_path = '{header_content_guard_href}remove_role/'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(header_content_guard_href, header_content_guard, opts = {}) ⇒ HeaderContentGuardResponse
Update a header content guard Content guard to protect the content app using a specific header.
705 706 707 708 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 705 def update(header_content_guard_href, header_content_guard, opts = {}) data, _status_code, _headers = update_with_http_info(header_content_guard_href, header_content_guard, opts) data end |
#update_with_http_info(header_content_guard_href, header_content_guard, opts = {}) ⇒ Array<(HeaderContentGuardResponse, Integer, Hash)>
Update a header content guard Content guard to protect the content app using a specific header.
717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 |
# File 'lib/pulpcore_client/api/contentguards_header_api.rb', line 717 def update_with_http_info(header_content_guard_href, header_content_guard, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentguardsHeaderApi.update ...' end # verify the required parameter 'header_content_guard_href' is set if @api_client.config.client_side_validation && header_content_guard_href.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard_href' when calling ContentguardsHeaderApi.update" end # verify the required parameter 'header_content_guard' is set if @api_client.config.client_side_validation && header_content_guard.nil? fail ArgumentError, "Missing the required parameter 'header_content_guard' when calling ContentguardsHeaderApi.update" end # resource path local_var_path = '{header_content_guard_href}'.sub('{' + 'header_content_guard_href' + '}', CGI.escape(header_content_guard_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(header_content_guard) # return_type return_type = opts[:return_type] || 'HeaderContentGuardResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentguardsHeaderApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |