Class: PulpcoreClient::Datarepair7465Api
- Inherits:
-
Object
- Object
- PulpcoreClient::Datarepair7465Api
- Defined in:
- lib/pulpcore_client/api/datarepair7465_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ Datarepair7465Api
constructor
A new instance of Datarepair7465Api.
-
#post(data_repair7465, opts = {}) ⇒ AsyncOperationResponse
Add Repository Version Content IDs (Issue #7465) Trigger an asynchronous task that adds missing repository version content_ids cache to all repository versions (Issue #7465).
-
#post_with_http_info(data_repair7465, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Add Repository Version Content IDs (Issue #7465) Trigger an asynchronous task that adds missing repository version content_ids cache to all repository versions (Issue #7465).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ Datarepair7465Api
Returns a new instance of Datarepair7465Api.
19 20 21 |
# File 'lib/pulpcore_client/api/datarepair7465_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulpcore_client/api/datarepair7465_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#post(data_repair7465, opts = {}) ⇒ AsyncOperationResponse
Add Repository Version Content IDs (Issue #7465) Trigger an asynchronous task that adds missing repository version content_ids cache to all repository versions (Issue #7465).
28 29 30 31 |
# File 'lib/pulpcore_client/api/datarepair7465_api.rb', line 28 def post(data_repair7465, opts = {}) data, _status_code, _headers = post_with_http_info(data_repair7465, opts) data end |
#post_with_http_info(data_repair7465, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Add Repository Version Content IDs (Issue #7465) Trigger an asynchronous task that adds missing repository version content_ids cache to all repository versions (Issue #7465).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/pulpcore_client/api/datarepair7465_api.rb', line 39 def post_with_http_info(data_repair7465, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: Datarepair7465Api.post ...' end # verify the required parameter 'data_repair7465' is set if @api_client.config.client_side_validation && data_repair7465.nil? fail ArgumentError, "Missing the required parameter 'data_repair7465' when calling Datarepair7465Api.post" end # resource path local_var_path = '/pulp/api/v3/datarepair/7465/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(data_repair7465) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"Datarepair7465Api.post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: Datarepair7465Api#post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |