Class: PulpcoreClient::Domain

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/models/domain.rb

Overview

Serializer for Domain.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Domain

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/pulpcore_client/models/domain.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::Domain` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::Domain`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'storage_class')
    self.storage_class = attributes[:'storage_class']
  else
    self.storage_class = nil
  end

  if attributes.key?(:'storage_settings')
    self.storage_settings = attributes[:'storage_settings']
  else
    self.storage_settings = nil
  end

  if attributes.key?(:'redirect_to_object_storage')
    self.redirect_to_object_storage = attributes[:'redirect_to_object_storage']
  else
    self.redirect_to_object_storage = true
  end

  if attributes.key?(:'hide_guarded_distributions')
    self.hide_guarded_distributions = attributes[:'hide_guarded_distributions']
  else
    self.hide_guarded_distributions = false
  end

  if attributes.key?(:'default_content_guard')
    self.default_content_guard = attributes[:'default_content_guard']
  end
end

Instance Attribute Details

#default_content_guardObject

An optional content-guard that is automatically assigned to new distributions created within this domain when they do not specify their own content-guard. To apply multiple guards by default, use a composite content-guard.



40
41
42
# File 'lib/pulpcore_client/models/domain.rb', line 40

def default_content_guard
  @default_content_guard
end

#descriptionObject

An optional description.



23
24
25
# File 'lib/pulpcore_client/models/domain.rb', line 23

def description
  @description
end

#hide_guarded_distributionsObject

Boolean to hide distributions with a content guard in the content app.



37
38
39
# File 'lib/pulpcore_client/models/domain.rb', line 37

def hide_guarded_distributions
  @hide_guarded_distributions
end

#nameObject

A name for this domain.



20
21
22
# File 'lib/pulpcore_client/models/domain.rb', line 20

def name
  @name
end

#pulp_labelsObject

Returns the value of attribute pulp_labels.



25
26
27
# File 'lib/pulpcore_client/models/domain.rb', line 25

def pulp_labels
  @pulp_labels
end

#redirect_to_object_storageObject

Boolean to have the content app redirect to object storage.



34
35
36
# File 'lib/pulpcore_client/models/domain.rb', line 34

def redirect_to_object_storage
  @redirect_to_object_storage
end

#storage_classObject

Backend storage class for domain. * pulpcore.app.models.storage.FileSystem - Use local filesystem as storage * storages.backends.s3boto3.S3Boto3Storage - Use Amazon S3 as storage [deprecated] * storages.backends.s3.S3Storage - Use Amazon S3 as storage * storages.backends.azure_storage.AzureStorage - Use Azure Blob as storage



28
29
30
# File 'lib/pulpcore_client/models/domain.rb', line 28

def storage_class
  @storage_class
end

#storage_settingsObject

Settings for storage class.



31
32
33
# File 'lib/pulpcore_client/models/domain.rb', line 31

def storage_settings
  @storage_settings
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/pulpcore_client/models/domain.rb', line 303

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpcoreClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/pulpcore_client/models/domain.rb', line 79

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/pulpcore_client/models/domain.rb', line 65

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'pulp_labels' => :'pulp_labels',
    :'storage_class' => :'storage_class',
    :'storage_settings' => :'storage_settings',
    :'redirect_to_object_storage' => :'redirect_to_object_storage',
    :'hide_guarded_distributions' => :'hide_guarded_distributions',
    :'default_content_guard' => :'default_content_guard'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/pulpcore_client/models/domain.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
103
# File 'lib/pulpcore_client/models/domain.rb', line 98

def self.openapi_nullable
  Set.new([
    :'description',
    :'default_content_guard'
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/pulpcore_client/models/domain.rb', line 84

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'pulp_labels' => :'Hash<String, String>',
    :'storage_class' => :'StorageClassEnum',
    :'storage_settings' => :'Object',
    :'redirect_to_object_storage' => :'Boolean',
    :'hide_guarded_distributions' => :'Boolean',
    :'default_content_guard' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/pulpcore_client/models/domain.rb', line 251

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      pulp_labels == o.pulp_labels &&
      storage_class == o.storage_class &&
      storage_settings == o.storage_settings &&
      redirect_to_object_storage == o.redirect_to_object_storage &&
      hide_guarded_distributions == o.hide_guarded_distributions &&
      default_content_guard == o.default_content_guard
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/pulpcore_client/models/domain.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/pulpcore_client/models/domain.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/pulpcore_client/models/domain.rb', line 272

def hash
  [name, description, pulp_labels, storage_class, storage_settings, redirect_to_object_storage, hide_guarded_distributions, default_content_guard].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/pulpcore_client/models/domain.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 50
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.')
  end

  if @storage_class.nil?
    invalid_properties.push('invalid value for "storage_class", storage_class cannot be nil.')
  end

  if @storage_settings.nil?
    invalid_properties.push('invalid value for "storage_settings", storage_settings cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
# File 'lib/pulpcore_client/models/domain.rb', line 350

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/pulpcore_client/models/domain.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



344
345
346
# File 'lib/pulpcore_client/models/domain.rb', line 344

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
211
212
213
214
# File 'lib/pulpcore_client/models/domain.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 50
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if !@description.nil? && @description.to_s.length < 1
  return false if @storage_class.nil?
  return false if @storage_settings.nil?
  true
end