Class: PulpcoreClient::DomainsApi
- Inherits:
-
Object
- Object
- PulpcoreClient::DomainsApi
- Defined in:
- lib/pulpcore_client/api/domains_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(domain, opts = {}) ⇒ DomainResponse
Create a domain ViewSet for Domain.
-
#create_with_http_info(domain, opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>
Create a domain ViewSet for Domain.
-
#delete(domain_href, opts = {}) ⇒ AsyncOperationResponse
Delete a domain Trigger an asynchronous delete task.
-
#delete_with_http_info(domain_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a domain Trigger an asynchronous delete task.
-
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
constructor
A new instance of DomainsApi.
-
#list(opts = {}) ⇒ PaginatedDomainResponseList
List domains ViewSet for Domain.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedDomainResponseList, Integer, Hash)>
List domains ViewSet for Domain.
-
#partial_update(domain_href, patched_domain, opts = {}) ⇒ AsyncOperationResponse
Update a domain Trigger an asynchronous partial update task.
-
#partial_update_with_http_info(domain_href, patched_domain, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a domain Trigger an asynchronous partial update task.
-
#read(domain_href, opts = {}) ⇒ DomainResponse
Inspect a domain ViewSet for Domain.
-
#read_with_http_info(domain_href, opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>
Inspect a domain ViewSet for Domain.
-
#update(domain_href, domain, opts = {}) ⇒ AsyncOperationResponse
Update a domain Trigger an asynchronous update task.
-
#update_with_http_info(domain_href, domain, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a domain Trigger an asynchronous update task.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
19 20 21 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(domain, opts = {}) ⇒ DomainResponse
Create a domain ViewSet for Domain. NOTE: This API endpoint is in "tech preview" and subject to change
28 29 30 31 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 28 def create(domain, opts = {}) data, _status_code, _headers = create_with_http_info(domain, opts) data end |
#create_with_http_info(domain, opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>
Create a domain ViewSet for Domain. NOTE: This API endpoint is in "tech preview" and subject to change
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 39 def create_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.create ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling DomainsApi.create" end # resource path local_var_path = '/pulp/api/v3/domains/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(domain) # return_type return_type = opts[:return_type] || 'DomainResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(domain_href, opts = {}) ⇒ AsyncOperationResponse
Delete a domain Trigger an asynchronous delete task
95 96 97 98 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 95 def delete(domain_href, opts = {}) data, _status_code, _headers = delete_with_http_info(domain_href, opts) data end |
#delete_with_http_info(domain_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a domain Trigger an asynchronous delete task
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 106 def delete_with_http_info(domain_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.delete ...' end # verify the required parameter 'domain_href' is set if @api_client.config.client_side_validation && domain_href.nil? fail ArgumentError, "Missing the required parameter 'domain_href' when calling DomainsApi.delete" end # resource path local_var_path = '{domain_href}'.sub('{' + 'domain_href' + '}', CGI.escape(domain_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedDomainResponseList
List domains ViewSet for Domain. NOTE: This API endpoint is in "tech preview" and subject to change
176 177 178 179 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 176 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedDomainResponseList, Integer, Hash)>
List domains ViewSet for Domain. NOTE: This API endpoint is in "tech preview" and subject to change
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 203 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.list ...' end allowable_values = ["-description", "-hide_guarded_distributions", "-name", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-redirect_to_object_storage", "-storage_class", "-storage_settings", "description", "hide_guarded_distributions", "name", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "redirect_to_object_storage", "storage_class", "storage_settings"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/domains/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__iregex'] = opts[:'name__iregex'] if !opts[:'name__iregex'].nil? query_params[:'name__istartswith'] = opts[:'name__istartswith'] if !opts[:'name__istartswith'].nil? query_params[:'name__regex'] = opts[:'name__regex'] if !opts[:'name__regex'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginatedDomainResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(domain_href, patched_domain, opts = {}) ⇒ AsyncOperationResponse
Update a domain Trigger an asynchronous partial update task
275 276 277 278 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 275 def partial_update(domain_href, patched_domain, opts = {}) data, _status_code, _headers = partial_update_with_http_info(domain_href, patched_domain, opts) data end |
#partial_update_with_http_info(domain_href, patched_domain, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a domain Trigger an asynchronous partial update task
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 287 def partial_update_with_http_info(domain_href, patched_domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.partial_update ...' end # verify the required parameter 'domain_href' is set if @api_client.config.client_side_validation && domain_href.nil? fail ArgumentError, "Missing the required parameter 'domain_href' when calling DomainsApi.partial_update" end # verify the required parameter 'patched_domain' is set if @api_client.config.client_side_validation && patched_domain.nil? fail ArgumentError, "Missing the required parameter 'patched_domain' when calling DomainsApi.partial_update" end # resource path local_var_path = '{domain_href}'.sub('{' + 'domain_href' + '}', CGI.escape(domain_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(patched_domain) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(domain_href, opts = {}) ⇒ DomainResponse
Inspect a domain ViewSet for Domain. NOTE: This API endpoint is in "tech preview" and subject to change
349 350 351 352 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 349 def read(domain_href, opts = {}) data, _status_code, _headers = read_with_http_info(domain_href, opts) data end |
#read_with_http_info(domain_href, opts = {}) ⇒ Array<(DomainResponse, Integer, Hash)>
Inspect a domain ViewSet for Domain. NOTE: This API endpoint is in "tech preview" and subject to change
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 362 def read_with_http_info(domain_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.read ...' end # verify the required parameter 'domain_href' is set if @api_client.config.client_side_validation && domain_href.nil? fail ArgumentError, "Missing the required parameter 'domain_href' when calling DomainsApi.read" end # resource path local_var_path = '{domain_href}'.sub('{' + 'domain_href' + '}', CGI.escape(domain_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'DomainResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(domain_href, domain, opts = {}) ⇒ AsyncOperationResponse
Update a domain Trigger an asynchronous update task
419 420 421 422 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 419 def update(domain_href, domain, opts = {}) data, _status_code, _headers = update_with_http_info(domain_href, domain, opts) data end |
#update_with_http_info(domain_href, domain, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a domain Trigger an asynchronous update task
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/pulpcore_client/api/domains_api.rb', line 431 def update_with_http_info(domain_href, domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.update ...' end # verify the required parameter 'domain_href' is set if @api_client.config.client_side_validation && domain_href.nil? fail ArgumentError, "Missing the required parameter 'domain_href' when calling DomainsApi.update" end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling DomainsApi.update" end # resource path local_var_path = '{domain_href}'.sub('{' + 'domain_href' + '}', CGI.escape(domain_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(domain) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |