Class: PulpcoreClient::GroupsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/api/groups_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ GroupsApi

Returns a new instance of GroupsApi.



19
20
21
# File 'lib/pulpcore_client/api/groups_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulpcore_client/api/groups_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_role(group_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Add a role Add a role for this object to users/groups.

Parameters:

  • group_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



29
30
31
32
# File 'lib/pulpcore_client/api/groups_api.rb', line 29

def add_role(group_href, nested_role, opts = {})
  data, _status_code, _headers = add_role_with_http_info(group_href, nested_role, opts)
  data
end

#add_role_with_http_info(group_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Add a role Add a role for this object to users/groups.

Parameters:

  • group_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(NestedRoleResponse, Integer, Hash)>)

    NestedRoleResponse data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/pulpcore_client/api/groups_api.rb', line 41

def add_role_with_http_info(group_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.add_role ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.add_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling GroupsApi.add_role"
  end
  # resource path
  local_var_path = '{group_href}add_role/'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create(group, opts = {}) ⇒ GroupResponse

Create a group ViewSet for Group.

Parameters:

  • group (Group)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



101
102
103
104
# File 'lib/pulpcore_client/api/groups_api.rb', line 101

def create(group, opts = {})
  data, _status_code, _headers = create_with_http_info(group, opts)
  data
end

#create_with_http_info(group, opts = {}) ⇒ Array<(GroupResponse, Integer, Hash)>

Create a group ViewSet for Group.

Parameters:

  • group (Group)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(GroupResponse, Integer, Hash)>)

    GroupResponse data, response status code and response headers



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pulpcore_client/api/groups_api.rb', line 112

def create_with_http_info(group, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.create ...'
  end
  # verify the required parameter 'group' is set
  if @api_client.config.client_side_validation && group.nil?
    fail ArgumentError, "Missing the required parameter 'group' when calling GroupsApi.create"
  end
  # resource path
  local_var_path = '/pulp/api/v3/groups/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(group) 

  # return_type
  return_type = opts[:return_type] || 'GroupResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(group_href, opts = {}) ⇒ nil

Delete a group ViewSet for Group.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (nil)


168
169
170
171
# File 'lib/pulpcore_client/api/groups_api.rb', line 168

def delete(group_href, opts = {})
  delete_with_http_info(group_href, opts)
  nil
end

#delete_with_http_info(group_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a group ViewSet for Group.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/pulpcore_client/api/groups_api.rb', line 179

def delete_with_http_info(group_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.delete ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.delete"
  end
  # resource path
  local_var_path = '{group_href}'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(opts = {}) ⇒ PaginatedGroupResponseList

List groups ViewSet for Group.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :id (Integer)

    Filter results where id matches value

  • :id__in (Array<Integer>)

    Filter results where id is in a comma-separated list of values

  • :limit (Integer)

    Number of results to return per page.

  • :name (String)

    Filter results where name matches value

  • :name__contains (String)

    Filter results where name contains value

  • :name__icontains (String)

    Filter results where name contains value

  • :name__iexact (String)

    Filter results where name matches value

  • :name__in (Array<String>)

    Filter results where name is in a comma-separated list of values

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * `id` - Id * `-id` - Id (descending) * `name` - Name * `-name` - Name (descending) * `pk` - Pk * `-pk` - Pk (descending)

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :q (String)
  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



245
246
247
248
# File 'lib/pulpcore_client/api/groups_api.rb', line 245

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end

#list_roles(group_href, opts = {}) ⇒ ObjectRolesResponse

List roles List roles assigned to this object.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



341
342
343
344
# File 'lib/pulpcore_client/api/groups_api.rb', line 341

def list_roles(group_href, opts = {})
  data, _status_code, _headers = list_roles_with_http_info(group_href, opts)
  data
end

#list_roles_with_http_info(group_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>

List roles List roles assigned to this object.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(ObjectRolesResponse, Integer, Hash)>)

    ObjectRolesResponse data, response status code and response headers



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/pulpcore_client/api/groups_api.rb', line 354

def list_roles_with_http_info(group_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.list_roles ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.list_roles"
  end
  # resource path
  local_var_path = '{group_href}list_roles/'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'ObjectRolesResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_with_http_info(opts = {}) ⇒ Array<(PaginatedGroupResponseList, Integer, Hash)>

List groups ViewSet for Group.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :id (Integer)

    Filter results where id matches value

  • :id__in (Array<Integer>)

    Filter results where id is in a comma-separated list of values

  • :limit (Integer)

    Number of results to return per page.

  • :name (String)

    Filter results where name matches value

  • :name__contains (String)

    Filter results where name contains value

  • :name__icontains (String)

    Filter results where name contains value

  • :name__iexact (String)

    Filter results where name matches value

  • :name__in (Array<String>)

    Filter results where name is in a comma-separated list of values

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * `id` - Id * `-id` - Id (descending) * `name` - Name * `-name` - Name (descending) * `pk` - Pk * `-pk` - Pk (descending)

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :q (String)
  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(PaginatedGroupResponseList, Integer, Hash)>)

    PaginatedGroupResponseList data, response status code and response headers



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/pulpcore_client/api/groups_api.rb', line 270

def list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.list ...'
  end
  allowable_values = ["-id", "-name", "-pk", "id", "name", "pk"]
  if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/pulp/api/v3/groups/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
  query_params[:'id__in'] = @api_client.build_collection_param(opts[:'id__in'], :csv) if !opts[:'id__in'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil?
  query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil?
  query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil?
  query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil?
  query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil?
  query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'PaginatedGroupResponseList' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#my_permissions(group_href, opts = {}) ⇒ MyPermissionsResponse

List user permissions List permissions available to the current user on this object.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



412
413
414
415
# File 'lib/pulpcore_client/api/groups_api.rb', line 412

def my_permissions(group_href, opts = {})
  data, _status_code, _headers = my_permissions_with_http_info(group_href, opts)
  data
end

#my_permissions_with_http_info(group_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>

List user permissions List permissions available to the current user on this object.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(MyPermissionsResponse, Integer, Hash)>)

    MyPermissionsResponse data, response status code and response headers



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/pulpcore_client/api/groups_api.rb', line 425

def my_permissions_with_http_info(group_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.my_permissions ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.my_permissions"
  end
  # resource path
  local_var_path = '{group_href}my_permissions/'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'MyPermissionsResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#partial_update(group_href, patched_group, opts = {}) ⇒ GroupResponse

Update a group ViewSet for Group.

Parameters:

  • group_href (String)
  • patched_group (PatchedGroup)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



482
483
484
485
# File 'lib/pulpcore_client/api/groups_api.rb', line 482

def partial_update(group_href, patched_group, opts = {})
  data, _status_code, _headers = partial_update_with_http_info(group_href, patched_group, opts)
  data
end

#partial_update_with_http_info(group_href, patched_group, opts = {}) ⇒ Array<(GroupResponse, Integer, Hash)>

Update a group ViewSet for Group.

Parameters:

  • group_href (String)
  • patched_group (PatchedGroup)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(GroupResponse, Integer, Hash)>)

    GroupResponse data, response status code and response headers



494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/pulpcore_client/api/groups_api.rb', line 494

def partial_update_with_http_info(group_href, patched_group, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.partial_update ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.partial_update"
  end
  # verify the required parameter 'patched_group' is set
  if @api_client.config.client_side_validation && patched_group.nil?
    fail ArgumentError, "Missing the required parameter 'patched_group' when calling GroupsApi.partial_update"
  end
  # resource path
  local_var_path = '{group_href}'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(patched_group) 

  # return_type
  return_type = opts[:return_type] || 'GroupResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(group_href, opts = {}) ⇒ GroupResponse

Inspect a group ViewSet for Group.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



556
557
558
559
# File 'lib/pulpcore_client/api/groups_api.rb', line 556

def read(group_href, opts = {})
  data, _status_code, _headers = read_with_http_info(group_href, opts)
  data
end

#read_with_http_info(group_href, opts = {}) ⇒ Array<(GroupResponse, Integer, Hash)>

Inspect a group ViewSet for Group.

Parameters:

  • group_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(GroupResponse, Integer, Hash)>)

    GroupResponse data, response status code and response headers



569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/pulpcore_client/api/groups_api.rb', line 569

def read_with_http_info(group_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.read ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.read"
  end
  # resource path
  local_var_path = '{group_href}'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'GroupResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_role(group_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Remove a role Remove a role for this object from users/groups.

Parameters:

  • group_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



626
627
628
629
# File 'lib/pulpcore_client/api/groups_api.rb', line 626

def remove_role(group_href, nested_role, opts = {})
  data, _status_code, _headers = remove_role_with_http_info(group_href, nested_role, opts)
  data
end

#remove_role_with_http_info(group_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Remove a role Remove a role for this object from users/groups.

Parameters:

  • group_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(NestedRoleResponse, Integer, Hash)>)

    NestedRoleResponse data, response status code and response headers



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
# File 'lib/pulpcore_client/api/groups_api.rb', line 638

def remove_role_with_http_info(group_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.remove_role ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.remove_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling GroupsApi.remove_role"
  end
  # resource path
  local_var_path = '{group_href}remove_role/'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update(group_href, group, opts = {}) ⇒ GroupResponse

Update a group ViewSet for Group.

Parameters:

  • group_href (String)
  • group (Group)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



699
700
701
702
# File 'lib/pulpcore_client/api/groups_api.rb', line 699

def update(group_href, group, opts = {})
  data, _status_code, _headers = update_with_http_info(group_href, group, opts)
  data
end

#update_with_http_info(group_href, group, opts = {}) ⇒ Array<(GroupResponse, Integer, Hash)>

Update a group ViewSet for Group.

Parameters:

  • group_href (String)
  • group (Group)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(GroupResponse, Integer, Hash)>)

    GroupResponse data, response status code and response headers



711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
# File 'lib/pulpcore_client/api/groups_api.rb', line 711

def update_with_http_info(group_href, group, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GroupsApi.update ...'
  end
  # verify the required parameter 'group_href' is set
  if @api_client.config.client_side_validation && group_href.nil?
    fail ArgumentError, "Missing the required parameter 'group_href' when calling GroupsApi.update"
  end
  # verify the required parameter 'group' is set
  if @api_client.config.client_side_validation && group.nil?
    fail ArgumentError, "Missing the required parameter 'group' when calling GroupsApi.update"
  end
  # resource path
  local_var_path = '{group_href}'.sub('{' + 'group_href' + '}', CGI.escape(group_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(group) 

  # return_type
  return_type = opts[:return_type] || 'GroupResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GroupsApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end