Class: PulpcoreClient::ImportersPulpImportsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/api/importers_pulp_imports_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ImportersPulpImportsApi

Returns a new instance of ImportersPulpImportsApi.



19
20
21
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create(pulp_importer_href, pulp_import, opts = {}) ⇒ TaskGroupOperationResponse

Create a pulp import Trigger an asynchronous task to import a Pulp export.

Parameters:

  • pulp_importer_href (String)
  • pulp_import (PulpImport)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



29
30
31
32
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 29

def create(pulp_importer_href, pulp_import, opts = {})
  data, _status_code, _headers = create_with_http_info(pulp_importer_href, pulp_import, opts)
  data
end

#create_with_http_info(pulp_importer_href, pulp_import, opts = {}) ⇒ Array<(TaskGroupOperationResponse, Integer, Hash)>

Create a pulp import Trigger an asynchronous task to import a Pulp export.

Parameters:

  • pulp_importer_href (String)
  • pulp_import (PulpImport)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(TaskGroupOperationResponse, Integer, Hash)>)

    TaskGroupOperationResponse data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 41

def create_with_http_info(pulp_importer_href, pulp_import, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ImportersPulpImportsApi.create ...'
  end
  # verify the required parameter 'pulp_importer_href' is set
  if @api_client.config.client_side_validation && pulp_importer_href.nil?
    fail ArgumentError, "Missing the required parameter 'pulp_importer_href' when calling ImportersPulpImportsApi.create"
  end
  # verify the required parameter 'pulp_import' is set
  if @api_client.config.client_side_validation && pulp_import.nil?
    fail ArgumentError, "Missing the required parameter 'pulp_import' when calling ImportersPulpImportsApi.create"
  end
  # resource path
  local_var_path = '{pulp_importer_href}imports/'.sub('{' + 'pulp_importer_href' + '}', CGI.escape(pulp_importer_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(pulp_import) 

  # return_type
  return_type = opts[:return_type] || 'TaskGroupOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ImportersPulpImportsApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(pulp_pulp_import_href, opts = {}) ⇒ nil

Delete a pulp import ViewSet for PulpImports.

Parameters:

  • pulp_pulp_import_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (nil)


101
102
103
104
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 101

def delete(pulp_pulp_import_href, opts = {})
  delete_with_http_info(pulp_pulp_import_href, opts)
  nil
end

#delete_with_http_info(pulp_pulp_import_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a pulp import ViewSet for PulpImports.

Parameters:

  • pulp_pulp_import_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 112

def delete_with_http_info(pulp_pulp_import_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ImportersPulpImportsApi.delete ...'
  end
  # verify the required parameter 'pulp_pulp_import_href' is set
  if @api_client.config.client_side_validation && pulp_pulp_import_href.nil?
    fail ArgumentError, "Missing the required parameter 'pulp_pulp_import_href' when calling ImportersPulpImportsApi.delete"
  end
  # resource path
  local_var_path = '{pulp_pulp_import_href}'.sub('{' + 'pulp_pulp_import_href' + '}', CGI.escape(pulp_pulp_import_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ImportersPulpImportsApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(pulp_importer_href, opts = {}) ⇒ PaginatedImportResponseList

List pulp imports ViewSet for PulpImports.

Parameters:

  • pulp_importer_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



168
169
170
171
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 168

def list(pulp_importer_href, opts = {})
  data, _status_code, _headers = list_with_http_info(pulp_importer_href, opts)
  data
end

#list_with_http_info(pulp_importer_href, opts = {}) ⇒ Array<(PaginatedImportResponseList, Integer, Hash)>

List pulp imports ViewSet for PulpImports.

Parameters:

  • pulp_importer_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(PaginatedImportResponseList, Integer, Hash)>)

    PaginatedImportResponseList data, response status code and response headers



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 183

def list_with_http_info(pulp_importer_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ImportersPulpImportsApi.list ...'
  end
  # verify the required parameter 'pulp_importer_href' is set
  if @api_client.config.client_side_validation && pulp_importer_href.nil?
    fail ArgumentError, "Missing the required parameter 'pulp_importer_href' when calling ImportersPulpImportsApi.list"
  end
  # resource path
  local_var_path = '{pulp_importer_href}imports/'.sub('{' + 'pulp_importer_href' + '}', CGI.escape(pulp_importer_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'PaginatedImportResponseList' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ImportersPulpImportsApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(pulp_pulp_import_href, opts = {}) ⇒ ImportResponse

Inspect a pulp import ViewSet for PulpImports.

Parameters:

  • pulp_pulp_import_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



243
244
245
246
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 243

def read(pulp_pulp_import_href, opts = {})
  data, _status_code, _headers = read_with_http_info(pulp_pulp_import_href, opts)
  data
end

#read_with_http_info(pulp_pulp_import_href, opts = {}) ⇒ Array<(ImportResponse, Integer, Hash)>

Inspect a pulp import ViewSet for PulpImports.

Parameters:

  • pulp_pulp_import_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(ImportResponse, Integer, Hash)>)

    ImportResponse data, response status code and response headers



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pulpcore_client/api/importers_pulp_imports_api.rb', line 256

def read_with_http_info(pulp_pulp_import_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ImportersPulpImportsApi.read ...'
  end
  # verify the required parameter 'pulp_pulp_import_href' is set
  if @api_client.config.client_side_validation && pulp_pulp_import_href.nil?
    fail ArgumentError, "Missing the required parameter 'pulp_pulp_import_href' when calling ImportersPulpImportsApi.read"
  end
  # resource path
  local_var_path = '{pulp_pulp_import_href}'.sub('{' + 'pulp_pulp_import_href' + '}', CGI.escape(pulp_pulp_import_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'ImportResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ImportersPulpImportsApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end