Class: PulpcoreClient::MinimalTaskResponse
- Inherits:
-
Object
- Object
- PulpcoreClient::MinimalTaskResponse
- Defined in:
- lib/pulpcore_client/models/minimal_task_response.rb
Overview
Base serializer for use with [pulpcore.app.models.Model][] This ensures that all Serializers provide values for the 'pulp_href` field. The class provides a default for the ref_name attribute in the ModelSerializers's Meta class. This ensures that the OpenAPI definitions of plugins are namespaced properly.
Instance Attribute Summary collapse
-
#finished_at ⇒ Object
Timestamp of when this task stopped execution.
-
#name ⇒ Object
The name of task.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#pulp_api_version ⇒ Object
The API-version that was invoked when creating the task.
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#started_at ⇒ Object
Timestamp of when this task started execution.
-
#state ⇒ Object
The current state of the task.
-
#unblocked_at ⇒ Object
Timestamp of when this task was identified ready for pickup.
-
#worker ⇒ Object
DEPRECATED - Always null.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MinimalTaskResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MinimalTaskResponse
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::MinimalTaskResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::MinimalTaskResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'pulp_api_version') self.pulp_api_version = attributes[:'pulp_api_version'] else self.pulp_api_version = 'v3' end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'unblocked_at') self.unblocked_at = attributes[:'unblocked_at'] end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'finished_at') self.finished_at = attributes[:'finished_at'] end if attributes.key?(:'worker') self.worker = attributes[:'worker'] end end |
Instance Attribute Details
#finished_at ⇒ Object
Timestamp of when this task stopped execution.
46 47 48 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 46 def finished_at @finished_at end |
#name ⇒ Object
The name of task.
34 35 36 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 34 def name @name end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 22 def prn @prn end |
#pulp_api_version ⇒ Object
The API-version that was invoked when creating the task.
31 32 33 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 31 def pulp_api_version @pulp_api_version end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
28 29 30 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#started_at ⇒ Object
Timestamp of when this task started execution.
43 44 45 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 43 def started_at @started_at end |
#state ⇒ Object
The current state of the task. The possible values include: 'waiting', 'skipped', 'running', 'completed', 'failed', 'canceled' and 'canceling'.
37 38 39 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 37 def state @state end |
#unblocked_at ⇒ Object
Timestamp of when this task was identified ready for pickup.
40 41 42 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 40 def unblocked_at @unblocked_at end |
#worker ⇒ Object
DEPRECATED - Always null
49 50 51 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 49 def worker @worker end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 238 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpcoreClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 69 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 52 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'pulp_api_version' => :'pulp_api_version', :'name' => :'name', :'state' => :'state', :'unblocked_at' => :'unblocked_at', :'started_at' => :'started_at', :'finished_at' => :'finished_at', :'worker' => :'worker' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 95 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 91 def self.openapi_nullable Set.new([ :'worker' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 74 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'pulp_api_version' => :'String', :'name' => :'String', :'state' => :'String', :'unblocked_at' => :'Time', :'started_at' => :'Time', :'finished_at' => :'Time', :'worker' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && pulp_api_version == o.pulp_api_version && name == o.name && state == o.state && unblocked_at == o.unblocked_at && started_at == o.started_at && finished_at == o.finished_at && worker == o.worker end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 309 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 207 def hash [pulp_href, prn, pulp_created, pulp_last_updated, pulp_api_version, name, state, unblocked_at, started_at, finished_at, worker].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
285 286 287 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 285 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 291 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
279 280 281 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 279 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 |
# File 'lib/pulpcore_client/models/minimal_task_response.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |