Class: PulpcoreClient::RemoteNetworkConfigResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/models/remote_network_config_response.rb

Overview

Shared network configuration fields and validation logic used by both RemoteSerializer and UploadSerializerFieldsMixin.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RemoteNetworkConfigResponse

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::RemoteNetworkConfigResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::RemoteNetworkConfigResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ca_cert')
    self.ca_cert = attributes[:'ca_cert']
  end

  if attributes.key?(:'client_cert')
    self.client_cert = attributes[:'client_cert']
  end

  if attributes.key?(:'tls_validation')
    self.tls_validation = attributes[:'tls_validation']
  end

  if attributes.key?(:'proxy_url')
    self.proxy_url = attributes[:'proxy_url']
  end

  if attributes.key?(:'max_retries')
    self.max_retries = attributes[:'max_retries']
  end

  if attributes.key?(:'total_timeout')
    self.total_timeout = attributes[:'total_timeout']
  end

  if attributes.key?(:'connect_timeout')
    self.connect_timeout = attributes[:'connect_timeout']
  end

  if attributes.key?(:'sock_connect_timeout')
    self.sock_connect_timeout = attributes[:'sock_connect_timeout']
  end

  if attributes.key?(:'sock_read_timeout')
    self.sock_read_timeout = attributes[:'sock_read_timeout']
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  end

  if attributes.key?(:'download_concurrency')
    self.download_concurrency = attributes[:'download_concurrency']
  end

  if attributes.key?(:'rate_limit')
    self.rate_limit = attributes[:'rate_limit']
  end
end

Instance Attribute Details

#ca_certObject

A PEM encoded CA certificate used to validate the server certificate presented by the remote server.



20
21
22
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 20

def ca_cert
  @ca_cert
end

#client_certObject

A PEM encoded client certificate used for authentication.



23
24
25
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 23

def client_cert
  @client_cert
end

#connect_timeoutObject

aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



38
39
40
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 38

def connect_timeout
  @connect_timeout
end

#download_concurrencyObject

Total number of simultaneous connections. If not set then the default value will be used.



50
51
52
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 50

def download_concurrency
  @download_concurrency
end

#headersObject

Headers for aiohttp.Clientsession



47
48
49
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 47

def headers
  @headers
end

#max_retriesObject

Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.



32
33
34
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 32

def max_retries
  @max_retries
end

#proxy_urlObject

The proxy URL. Format: scheme://host:port



29
30
31
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 29

def proxy_url
  @proxy_url
end

#rate_limitObject

Limits requests per second for each concurrent downloader



53
54
55
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 53

def rate_limit
  @rate_limit
end

#sock_connect_timeoutObject

aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



41
42
43
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 41

def sock_connect_timeout
  @sock_connect_timeout
end

#sock_read_timeoutObject

aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



44
45
46
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 44

def sock_read_timeout
  @sock_read_timeout
end

#tls_validationObject

If True, TLS peer validation must be performed.



26
27
28
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 26

def tls_validation
  @tls_validation
end

#total_timeoutObject

aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



35
36
37
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 35

def total_timeout
  @total_timeout
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 326

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpcoreClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 56

def self.attribute_map
  {
    :'ca_cert' => :'ca_cert',
    :'client_cert' => :'client_cert',
    :'tls_validation' => :'tls_validation',
    :'proxy_url' => :'proxy_url',
    :'max_retries' => :'max_retries',
    :'total_timeout' => :'total_timeout',
    :'connect_timeout' => :'connect_timeout',
    :'sock_connect_timeout' => :'sock_connect_timeout',
    :'sock_read_timeout' => :'sock_read_timeout',
    :'headers' => :'headers',
    :'download_concurrency' => :'download_concurrency',
    :'rate_limit' => :'rate_limit'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 302

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 97

def self.openapi_nullable
  Set.new([
    :'ca_cert',
    :'client_cert',
    :'proxy_url',
    :'max_retries',
    :'total_timeout',
    :'connect_timeout',
    :'sock_connect_timeout',
    :'sock_read_timeout',
    :'download_concurrency',
    :'rate_limit'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 79

def self.openapi_types
  {
    :'ca_cert' => :'String',
    :'client_cert' => :'String',
    :'tls_validation' => :'Boolean',
    :'proxy_url' => :'String',
    :'max_retries' => :'Integer',
    :'total_timeout' => :'Float',
    :'connect_timeout' => :'Float',
    :'sock_connect_timeout' => :'Float',
    :'sock_read_timeout' => :'Float',
    :'headers' => :'Array<Object>',
    :'download_concurrency' => :'Integer',
    :'rate_limit' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 270

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ca_cert == o.ca_cert &&
      client_cert == o.client_cert &&
      tls_validation == o.tls_validation &&
      proxy_url == o.proxy_url &&
      max_retries == o.max_retries &&
      total_timeout == o.total_timeout &&
      connect_timeout == o.connect_timeout &&
      sock_connect_timeout == o.sock_connect_timeout &&
      sock_read_timeout == o.sock_read_timeout &&
      headers == o.headers &&
      download_concurrency == o.download_concurrency &&
      rate_limit == o.rate_limit
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 397

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • to be compared

Returns:



289
290
291
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 289

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



295
296
297
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 295

def hash
  [ca_cert, client_cert, tls_validation, proxy_url, max_retries, total_timeout, connect_timeout, sock_connect_timeout, sock_read_timeout, headers, download_concurrency, rate_limit].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@total_timeout.nil? && @total_timeout < 0.0
    invalid_properties.push('invalid value for "total_timeout", must be greater than or equal to 0.0.')
  end

  if !@connect_timeout.nil? && @connect_timeout < 0.0
    invalid_properties.push('invalid value for "connect_timeout", must be greater than or equal to 0.0.')
  end

  if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0
    invalid_properties.push('invalid value for "sock_connect_timeout", must be greater than or equal to 0.0.')
  end

  if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0
    invalid_properties.push('invalid value for "sock_read_timeout", must be greater than or equal to 0.0.')
  end

  if !@download_concurrency.nil? && @download_concurrency < 1
    invalid_properties.push('invalid value for "download_concurrency", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



373
374
375
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 373

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 379

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



367
368
369
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 367

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



208
209
210
211
212
213
214
215
216
# File 'lib/pulpcore_client/models/remote_network_config_response.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@total_timeout.nil? && @total_timeout < 0.0
  return false if !@connect_timeout.nil? && @connect_timeout < 0.0
  return false if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0
  return false if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0
  return false if !@download_concurrency.nil? && @download_concurrency < 1
  true
end