Class: PulpcoreClient::TasksApi
- Inherits:
-
Object
- Object
- PulpcoreClient::TasksApi
- Defined in:
- lib/pulpcore_client/api/tasks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
-
#add_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
-
#delete(task_href, opts = {}) ⇒ nil
Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router.
-
#delete_with_http_info(task_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router.
-
#initialize(api_client = ApiClient.default) ⇒ TasksApi
constructor
A new instance of TasksApi.
-
#list(opts = {}) ⇒ PaginatedTaskResponseList
List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router.
-
#list_roles(task_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
-
#list_roles_with_http_info(task_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedTaskResponseList, Integer, Hash)>
List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router.
-
#my_permissions(task_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
-
#my_permissions_with_http_info(task_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
-
#profile_artifacts(task_href, opts = {}) ⇒ ProfileArtifactResponse
Fetch downloadable links for profile artifacts Return pre-signed URLs used for downloading raw profile artifacts.
-
#profile_artifacts_with_http_info(task_href, opts = {}) ⇒ Array<(ProfileArtifactResponse, Integer, Hash)>
Fetch downloadable links for profile artifacts Return pre-signed URLs used for downloading raw profile artifacts.
-
#purge(purge, opts = {}) ⇒ AsyncOperationResponse
Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp.
-
#purge_with_http_info(purge, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp.
-
#read(task_href, opts = {}) ⇒ TaskResponse
Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router.
-
#read_with_http_info(task_href, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>
Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router.
-
#remove_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
-
#remove_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
-
#tasks_cancel(task_href, patched_task_cancel, opts = {}) ⇒ TaskResponse
Cancel a task This operation cancels a task.
-
#tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>
Cancel a task This operation cancels a task.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TasksApi
Returns a new instance of TasksApi.
19 20 21 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
28 29 30 31 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 28 def add_role(task_href, nested_role, opts = {}) data, _status_code, _headers = add_role_with_http_info(task_href, nested_role, opts) data end |
#add_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 39 def add_role_with_http_info(task_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.add_role ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.add_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling TasksApi.add_role" end # resource path local_var_path = '{task_href}add_role/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:debug_return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.add_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(task_href, opts = {}) ⇒ nil
Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to ‘pk’ endpoint_name (str): The name of the final path segment that should identify the ViewSet’s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object’s identity. schema (DefaultSchema): The schema class to use by default in a viewset.
101 102 103 104 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 101 def delete(task_href, opts = {}) delete_with_http_info(task_href, opts) nil end |
#delete_with_http_info(task_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the ``register_with`` method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 111 def delete_with_http_info(task_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.delete ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.delete" end # resource path local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedTaskResponseList
List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to ‘pk’ endpoint_name (str): The name of the final path segment that should identify the ViewSet’s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object’s identity. schema (DefaultSchema): The schema class to use by default in a viewset.
213 214 215 216 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 213 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_roles(task_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
385 386 387 388 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 385 def list_roles(task_href, opts = {}) data, _status_code, _headers = list_roles_with_http_info(task_href, opts) data end |
#list_roles_with_http_info(task_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 397 def list_roles_with_http_info(task_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.list_roles ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.list_roles" end # resource path local_var_path = '{task_href}list_roles/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ObjectRolesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.list_roles", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedTaskResponseList, Integer, Hash)>
List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the ``register_with`` method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 274 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.list ...' end allowable_values = ["-deferred", "-enc_args", "-enc_kwargs", "-error", "-finished_at", "-immediate", "-logging_cid", "-name", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-reserved_resources_record", "-started_at", "-state", "-unblocked_at", "-versions", "deferred", "enc_args", "enc_kwargs", "error", "finished_at", "immediate", "logging_cid", "name", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "reserved_resources_record", "started_at", "state", "unblocked_at", "versions"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end allowable_values = ["canceled", "canceling", "completed", "failed", "running", "skipped", "waiting"] if @api_client.config.client_side_validation && opts[:'state'] && !allowable_values.include?(opts[:'state']) fail ArgumentError, "invalid value for \"state\", must be one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/tasks/' # query parameters query_params = opts[:query_params] || {} query_params[:'child_tasks'] = opts[:'child_tasks'] if !opts[:'child_tasks'].nil? query_params[:'created_resources'] = opts[:'created_resources'] if !opts[:'created_resources'].nil? query_params[:'exclusive_resources'] = opts[:'exclusive_resources'] if !opts[:'exclusive_resources'].nil? query_params[:'exclusive_resources__in'] = @api_client.build_collection_param(opts[:'exclusive_resources__in'], :csv) if !opts[:'exclusive_resources__in'].nil? query_params[:'finished_at'] = opts[:'finished_at'] if !opts[:'finished_at'].nil? query_params[:'finished_at__gt'] = opts[:'finished_at__gt'] if !opts[:'finished_at__gt'].nil? query_params[:'finished_at__gte'] = opts[:'finished_at__gte'] if !opts[:'finished_at__gte'].nil? query_params[:'finished_at__isnull'] = opts[:'finished_at__isnull'] if !opts[:'finished_at__isnull'].nil? query_params[:'finished_at__lt'] = opts[:'finished_at__lt'] if !opts[:'finished_at__lt'].nil? query_params[:'finished_at__lte'] = opts[:'finished_at__lte'] if !opts[:'finished_at__lte'].nil? query_params[:'finished_at__range'] = @api_client.build_collection_param(opts[:'finished_at__range'], :csv) if !opts[:'finished_at__range'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'logging_cid'] = opts[:'logging_cid'] if !opts[:'logging_cid'].nil? query_params[:'logging_cid__contains'] = opts[:'logging_cid__contains'] if !opts[:'logging_cid__contains'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__ne'] = opts[:'name__ne'] if !opts[:'name__ne'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'parent_task'] = opts[:'parent_task'] if !opts[:'parent_task'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'reserved_resources'] = opts[:'reserved_resources'] if !opts[:'reserved_resources'].nil? query_params[:'reserved_resources__in'] = @api_client.build_collection_param(opts[:'reserved_resources__in'], :csv) if !opts[:'reserved_resources__in'].nil? query_params[:'shared_resources'] = opts[:'shared_resources'] if !opts[:'shared_resources'].nil? query_params[:'shared_resources__in'] = @api_client.build_collection_param(opts[:'shared_resources__in'], :csv) if !opts[:'shared_resources__in'].nil? query_params[:'started_at'] = opts[:'started_at'] if !opts[:'started_at'].nil? query_params[:'started_at__gt'] = opts[:'started_at__gt'] if !opts[:'started_at__gt'].nil? query_params[:'started_at__gte'] = opts[:'started_at__gte'] if !opts[:'started_at__gte'].nil? query_params[:'started_at__isnull'] = opts[:'started_at__isnull'] if !opts[:'started_at__isnull'].nil? query_params[:'started_at__lt'] = opts[:'started_at__lt'] if !opts[:'started_at__lt'].nil? query_params[:'started_at__lte'] = opts[:'started_at__lte'] if !opts[:'started_at__lte'].nil? query_params[:'started_at__range'] = @api_client.build_collection_param(opts[:'started_at__range'], :csv) if !opts[:'started_at__range'].nil? query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil? query_params[:'state__in'] = @api_client.build_collection_param(opts[:'state__in'], :csv) if !opts[:'state__in'].nil? query_params[:'state__ne'] = opts[:'state__ne'] if !opts[:'state__ne'].nil? query_params[:'task_group'] = opts[:'task_group'] if !opts[:'task_group'].nil? query_params[:'unblocked_at'] = opts[:'unblocked_at'] if !opts[:'unblocked_at'].nil? query_params[:'unblocked_at__gt'] = opts[:'unblocked_at__gt'] if !opts[:'unblocked_at__gt'].nil? query_params[:'unblocked_at__gte'] = opts[:'unblocked_at__gte'] if !opts[:'unblocked_at__gte'].nil? query_params[:'unblocked_at__isnull'] = opts[:'unblocked_at__isnull'] if !opts[:'unblocked_at__isnull'].nil? query_params[:'unblocked_at__lt'] = opts[:'unblocked_at__lt'] if !opts[:'unblocked_at__lt'].nil? query_params[:'unblocked_at__lte'] = opts[:'unblocked_at__lte'] if !opts[:'unblocked_at__lte'].nil? query_params[:'unblocked_at__range'] = @api_client.build_collection_param(opts[:'unblocked_at__range'], :csv) if !opts[:'unblocked_at__range'].nil? query_params[:'worker'] = opts[:'worker'] if !opts[:'worker'].nil? query_params[:'worker__in'] = @api_client.build_collection_param(opts[:'worker__in'], :csv) if !opts[:'worker__in'].nil? query_params[:'worker__isnull'] = opts[:'worker__isnull'] if !opts[:'worker__isnull'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedTaskResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#my_permissions(task_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
454 455 456 457 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 454 def (task_href, opts = {}) data, _status_code, _headers = (task_href, opts) data end |
#my_permissions_with_http_info(task_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 466 def (task_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.my_permissions ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.my_permissions" end # resource path local_var_path = '{task_href}my_permissions/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MyPermissionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.my_permissions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#profile_artifacts(task_href, opts = {}) ⇒ ProfileArtifactResponse
Fetch downloadable links for profile artifacts Return pre-signed URLs used for downloading raw profile artifacts.
523 524 525 526 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 523 def profile_artifacts(task_href, opts = {}) data, _status_code, _headers = profile_artifacts_with_http_info(task_href, opts) data end |
#profile_artifacts_with_http_info(task_href, opts = {}) ⇒ Array<(ProfileArtifactResponse, Integer, Hash)>
Fetch downloadable links for profile artifacts Return pre-signed URLs used for downloading raw profile artifacts.
535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 535 def profile_artifacts_with_http_info(task_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.profile_artifacts ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.profile_artifacts" end # resource path local_var_path = '{task_href}profile_artifacts/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProfileArtifactResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.profile_artifacts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#profile_artifacts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#purge(purge, opts = {}) ⇒ AsyncOperationResponse
Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp.
590 591 592 593 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 590 def purge(purge, opts = {}) data, _status_code, _headers = purge_with_http_info(purge, opts) data end |
#purge_with_http_info(purge, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 600 def purge_with_http_info(purge, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.purge ...' end # verify the required parameter 'purge' is set if @api_client.config.client_side_validation && purge.nil? fail ArgumentError, "Missing the required parameter 'purge' when calling TasksApi.purge" end # resource path local_var_path = '/pulp/api/v3/tasks/purge/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(purge) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.purge", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#purge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(task_href, opts = {}) ⇒ TaskResponse
Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to ‘pk’ endpoint_name (str): The name of the final path segment that should identify the ViewSet’s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object’s identity. schema (DefaultSchema): The schema class to use by default in a viewset.
660 661 662 663 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 660 def read(task_href, opts = {}) data, _status_code, _headers = read_with_http_info(task_href, opts) data end |
#read_with_http_info(task_href, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>
Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the ``register_with`` method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.
672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 672 def read_with_http_info(task_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.read ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.read" end # resource path local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TaskResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
728 729 730 731 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 728 def remove_role(task_href, nested_role, opts = {}) data, _status_code, _headers = remove_role_with_http_info(task_href, nested_role, opts) data end |
#remove_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 739 def remove_role_with_http_info(task_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.remove_role ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.remove_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling TasksApi.remove_role" end # resource path local_var_path = '{task_href}remove_role/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:debug_return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.remove_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#tasks_cancel(task_href, patched_task_cancel, opts = {}) ⇒ TaskResponse
Cancel a task This operation cancels a task.
802 803 804 805 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 802 def tasks_cancel(task_href, patched_task_cancel, opts = {}) data, _status_code, _headers = tasks_cancel_with_http_info(task_href, patched_task_cancel, opts) data end |
#tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>
Cancel a task This operation cancels a task.
813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/pulpcore_client/api/tasks_api.rb', line 813 def tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TasksApi.tasks_cancel ...' end # verify the required parameter 'task_href' is set if @api_client.config.client_side_validation && task_href.nil? fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_cancel" end # verify the required parameter 'patched_task_cancel' is set if @api_client.config.client_side_validation && patched_task_cancel.nil? fail ArgumentError, "Missing the required parameter 'patched_task_cancel' when calling TasksApi.tasks_cancel" end # resource path local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patched_task_cancel) # return_type return_type = opts[:debug_return_type] || 'TaskResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"TasksApi.tasks_cancel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TasksApi#tasks_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |