Class: PulpcoreClient::UpstreamPulp

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/models/upstream_pulp.rb

Overview

Serializer for a Server.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpstreamPulp

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 169

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::UpstreamPulp` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::UpstreamPulp`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  else
    self.base_url = nil
  end

  if attributes.key?(:'api_root')
    self.api_root = attributes[:'api_root']
  else
    self.api_root = nil
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  end

  if attributes.key?(:'ca_cert')
    self.ca_cert = attributes[:'ca_cert']
  end

  if attributes.key?(:'client_cert')
    self.client_cert = attributes[:'client_cert']
  end

  if attributes.key?(:'client_key')
    self.client_key = attributes[:'client_key']
  end

  if attributes.key?(:'tls_validation')
    self.tls_validation = attributes[:'tls_validation']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'download_concurrency')
    self.download_concurrency = attributes[:'download_concurrency']
  end

  if attributes.key?(:'max_retries')
    self.max_retries = attributes[:'max_retries']
  end

  if attributes.key?(:'total_timeout')
    self.total_timeout = attributes[:'total_timeout']
  end

  if attributes.key?(:'connect_timeout')
    self.connect_timeout = attributes[:'connect_timeout']
  end

  if attributes.key?(:'sock_connect_timeout')
    self.sock_connect_timeout = attributes[:'sock_connect_timeout']
  end

  if attributes.key?(:'sock_read_timeout')
    self.sock_read_timeout = attributes[:'sock_read_timeout']
  end

  if attributes.key?(:'q_select')
    self.q_select = attributes[:'q_select']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end
end

Instance Attribute Details

#api_rootObject

The API root. Defaults to ‘/pulp/’.



26
27
28
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 26

def api_root
  @api_root
end

#base_urlObject

The transport, hostname, and an optional port of the Pulp server. e.g. example.com



23
24
25
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 23

def base_url
  @base_url
end

#ca_certObject

A PEM encoded CA certificate used to validate the server certificate presented by the remote server.



32
33
34
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 32

def ca_cert
  @ca_cert
end

#client_certObject

A PEM encoded client certificate used for authentication.



35
36
37
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 35

def client_cert
  @client_cert
end

#client_keyObject

A PEM encoded private key used for authentication.



38
39
40
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 38

def client_key
  @client_key
end

#connect_timeoutObject

aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



59
60
61
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 59

def connect_timeout
  @connect_timeout
end

#domainObject

The domain of the Pulp server if enabled.



29
30
31
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 29

def domain
  @domain
end

#download_concurrencyObject

Total number of simultaneous connections. If not set then the default value will be used.



50
51
52
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 50

def download_concurrency
  @download_concurrency
end

#max_retriesObject

Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.



53
54
55
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 53

def max_retries
  @max_retries
end

#nameObject

A unique name for this Pulp server.



20
21
22
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 20

def name
  @name
end

#passwordObject

The password to be used for authentication when syncing. Extra leading and trailing whitespace characters are not trimmed.



47
48
49
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 47

def password
  @password
end

#policyObject

Policy for how replicate will manage the local objects within the domain. * ‘all` - Replicate manages ALL local objects within the domain. * `labeled` - Replicate will only manage the objects created from a previous replication, unlabled local objects will be untouched. * `nodelete` - Replicate will not delete any local object whether they were created by replication or not.



71
72
73
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 71

def policy
  @policy
end

#q_selectObject

Filter distributions on the upstream Pulp using complex filtering. E.g. pulp_label_select="foo" OR pulp_label_select="key=val"



68
69
70
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 68

def q_select
  @q_select
end

#sock_connect_timeoutObject

aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



62
63
64
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 62

def sock_connect_timeout
  @sock_connect_timeout
end

#sock_read_timeoutObject

aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



65
66
67
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 65

def sock_read_timeout
  @sock_read_timeout
end

#tls_validationObject

If True, TLS peer validation must be performed.



41
42
43
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 41

def tls_validation
  @tls_validation
end

#total_timeoutObject

aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



56
57
58
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 56

def total_timeout
  @total_timeout
end

#usernameObject

The username to be used for authentication when syncing.



44
45
46
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 44

def username
  @username
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 577

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpcoreClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 120

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 96

def self.attribute_map
  {
    :'name' => :'name',
    :'base_url' => :'base_url',
    :'api_root' => :'api_root',
    :'domain' => :'domain',
    :'ca_cert' => :'ca_cert',
    :'client_cert' => :'client_cert',
    :'client_key' => :'client_key',
    :'tls_validation' => :'tls_validation',
    :'username' => :'username',
    :'password' => :'password',
    :'download_concurrency' => :'download_concurrency',
    :'max_retries' => :'max_retries',
    :'total_timeout' => :'total_timeout',
    :'connect_timeout' => :'connect_timeout',
    :'sock_connect_timeout' => :'sock_connect_timeout',
    :'sock_read_timeout' => :'sock_read_timeout',
    :'q_select' => :'q_select',
    :'policy' => :'policy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 553

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 149

def self.openapi_nullable
  Set.new([
    :'domain',
    :'ca_cert',
    :'client_cert',
    :'client_key',
    :'username',
    :'password',
    :'download_concurrency',
    :'max_retries',
    :'total_timeout',
    :'connect_timeout',
    :'sock_connect_timeout',
    :'sock_read_timeout',
    :'q_select',
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 125

def self.openapi_types
  {
    :'name' => :'String',
    :'base_url' => :'String',
    :'api_root' => :'String',
    :'domain' => :'String',
    :'ca_cert' => :'String',
    :'client_cert' => :'String',
    :'client_key' => :'String',
    :'tls_validation' => :'Boolean',
    :'username' => :'String',
    :'password' => :'String',
    :'download_concurrency' => :'Integer',
    :'max_retries' => :'Integer',
    :'total_timeout' => :'Float',
    :'connect_timeout' => :'Float',
    :'sock_connect_timeout' => :'Float',
    :'sock_read_timeout' => :'Float',
    :'q_select' => :'String',
    :'policy' => :'Policy357Enum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 515

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      base_url == o.base_url &&
      api_root == o.api_root &&
      domain == o.domain &&
      ca_cert == o.ca_cert &&
      client_cert == o.client_cert &&
      client_key == o.client_key &&
      tls_validation == o.tls_validation &&
      username == o.username &&
      password == o.password &&
      download_concurrency == o.download_concurrency &&
      max_retries == o.max_retries &&
      total_timeout == o.total_timeout &&
      connect_timeout == o.connect_timeout &&
      sock_connect_timeout == o.sock_connect_timeout &&
      sock_read_timeout == o.sock_read_timeout &&
      q_select == o.q_select &&
      policy == o.policy
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 648

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


540
541
542
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 540

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



546
547
548
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 546

def hash
  [name, base_url, api_root, domain, ca_cert, client_cert, client_key, tls_validation, username, password, download_concurrency, max_retries, total_timeout, connect_timeout, sock_connect_timeout, sock_read_timeout, q_select, policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 263

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @base_url.nil?
    invalid_properties.push('invalid value for "base_url", base_url cannot be nil.')
  end

  if @base_url.to_s.length < 1
    invalid_properties.push('invalid value for "base_url", the character length must be great than or equal to 1.')
  end

  if @api_root.nil?
    invalid_properties.push('invalid value for "api_root", api_root cannot be nil.')
  end

  if @api_root.to_s.length < 1
    invalid_properties.push('invalid value for "api_root", the character length must be great than or equal to 1.')
  end

  if !@domain.nil? && @domain.to_s.length < 1
    invalid_properties.push('invalid value for "domain", the character length must be great than or equal to 1.')
  end

  if !@ca_cert.nil? && @ca_cert.to_s.length < 1
    invalid_properties.push('invalid value for "ca_cert", the character length must be great than or equal to 1.')
  end

  if !@client_cert.nil? && @client_cert.to_s.length < 1
    invalid_properties.push('invalid value for "client_cert", the character length must be great than or equal to 1.')
  end

  if !@client_key.nil? && @client_key.to_s.length < 1
    invalid_properties.push('invalid value for "client_key", the character length must be great than or equal to 1.')
  end

  if !@username.nil? && @username.to_s.length < 1
    invalid_properties.push('invalid value for "username", the character length must be great than or equal to 1.')
  end

  if !@password.nil? && @password.to_s.length < 1
    invalid_properties.push('invalid value for "password", the character length must be great than or equal to 1.')
  end

  if !@download_concurrency.nil? && @download_concurrency < 1
    invalid_properties.push('invalid value for "download_concurrency", must be greater than or equal to 1.')
  end

  if !@total_timeout.nil? && @total_timeout < 0.0
    invalid_properties.push('invalid value for "total_timeout", must be greater than or equal to 0.0.')
  end

  if !@connect_timeout.nil? && @connect_timeout < 0.0
    invalid_properties.push('invalid value for "connect_timeout", must be greater than or equal to 0.0.')
  end

  if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0
    invalid_properties.push('invalid value for "sock_connect_timeout", must be greater than or equal to 0.0.')
  end

  if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0
    invalid_properties.push('invalid value for "sock_read_timeout", must be greater than or equal to 0.0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



624
625
626
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 624

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



630
631
632
633
634
635
636
637
638
639
640
641
642
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 630

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



618
619
620
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 618

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/pulpcore_client/models/upstream_pulp.rb', line 339

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @base_url.nil?
  return false if @base_url.to_s.length < 1
  return false if @api_root.nil?
  return false if @api_root.to_s.length < 1
  return false if !@domain.nil? && @domain.to_s.length < 1
  return false if !@ca_cert.nil? && @ca_cert.to_s.length < 1
  return false if !@client_cert.nil? && @client_cert.to_s.length < 1
  return false if !@client_key.nil? && @client_key.to_s.length < 1
  return false if !@username.nil? && @username.to_s.length < 1
  return false if !@password.nil? && @password.to_s.length < 1
  return false if !@download_concurrency.nil? && @download_concurrency < 1
  return false if !@total_timeout.nil? && @total_timeout < 0.0
  return false if !@connect_timeout.nil? && @connect_timeout < 0.0
  return false if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0
  return false if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0
  true
end