Class: PulpcoreClient::UpstreamPulpResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/models/upstream_pulp_response.rb

Overview

Serializer for a Server.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpstreamPulpResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 180

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::UpstreamPulpResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::UpstreamPulpResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_href')
    self.pulp_href = attributes[:'pulp_href']
  end

  if attributes.key?(:'prn')
    self.prn = attributes[:'prn']
  end

  if attributes.key?(:'pulp_created')
    self.pulp_created = attributes[:'pulp_created']
  end

  if attributes.key?(:'pulp_last_updated')
    self.pulp_last_updated = attributes[:'pulp_last_updated']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  else
    self.base_url = nil
  end

  if attributes.key?(:'api_root')
    self.api_root = attributes[:'api_root']
  else
    self.api_root = nil
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  end

  if attributes.key?(:'ca_cert')
    self.ca_cert = attributes[:'ca_cert']
  end

  if attributes.key?(:'client_cert')
    self.client_cert = attributes[:'client_cert']
  end

  if attributes.key?(:'tls_validation')
    self.tls_validation = attributes[:'tls_validation']
  end

  if attributes.key?(:'download_concurrency')
    self.download_concurrency = attributes[:'download_concurrency']
  end

  if attributes.key?(:'max_retries')
    self.max_retries = attributes[:'max_retries']
  end

  if attributes.key?(:'total_timeout')
    self.total_timeout = attributes[:'total_timeout']
  end

  if attributes.key?(:'connect_timeout')
    self.connect_timeout = attributes[:'connect_timeout']
  end

  if attributes.key?(:'sock_connect_timeout')
    self.sock_connect_timeout = attributes[:'sock_connect_timeout']
  end

  if attributes.key?(:'sock_read_timeout')
    self.sock_read_timeout = attributes[:'sock_read_timeout']
  end

  if attributes.key?(:'hidden_fields')
    if (value = attributes[:'hidden_fields']).is_a?(Array)
      self.hidden_fields = value
    end
  end

  if attributes.key?(:'q_select')
    self.q_select = attributes[:'q_select']
  end

  if attributes.key?(:'last_replication')
    self.last_replication = attributes[:'last_replication']
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end
end

Instance Attribute Details

#api_rootObject

The API root. Defaults to ‘/pulp/’.



37
38
39
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 37

def api_root
  @api_root
end

#base_urlObject

The transport, hostname, and an optional port of the Pulp server. e.g. example.com



34
35
36
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 34

def base_url
  @base_url
end

#ca_certObject

A PEM encoded CA certificate used to validate the server certificate presented by the remote server.



43
44
45
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 43

def ca_cert
  @ca_cert
end

#client_certObject

A PEM encoded client certificate used for authentication.



46
47
48
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 46

def client_cert
  @client_cert
end

#connect_timeoutObject

aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



61
62
63
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 61

def connect_timeout
  @connect_timeout
end

#domainObject

The domain of the Pulp server if enabled.



40
41
42
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 40

def domain
  @domain
end

#download_concurrencyObject

Total number of simultaneous connections. If not set then the default value will be used.



52
53
54
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 52

def download_concurrency
  @download_concurrency
end

#hidden_fieldsObject

List of hidden (write only) fields



70
71
72
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 70

def hidden_fields
  @hidden_fields
end

#last_replicationObject

Timestamp of the last replication that occurred. Equals to ‘null’ if no replication task has been executed.



76
77
78
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 76

def last_replication
  @last_replication
end

#max_retriesObject

Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.



55
56
57
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 55

def max_retries
  @max_retries
end

#nameObject

A unique name for this Pulp server.



31
32
33
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 31

def name
  @name
end

#policyObject

Policy for how replicate will manage the local objects within the domain. * ‘all` - Replicate manages ALL local objects within the domain. * `labeled` - Replicate will only manage the objects created from a previous replication, unlabled local objects will be untouched. * `nodelete` - Replicate will not delete any local object whether they were created by replication or not.



79
80
81
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 79

def policy
  @policy
end

#prnObject

The Pulp Resource Name (PRN).



22
23
24
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 22

def prn
  @prn
end

#pulp_createdObject

Timestamp of creation.



25
26
27
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 25

def pulp_created
  @pulp_created
end

#pulp_hrefObject

Returns the value of attribute pulp_href.



19
20
21
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 19

def pulp_href
  @pulp_href
end

#pulp_last_updatedObject

Timestamp of the most recent update of the remote.



28
29
30
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 28

def pulp_last_updated
  @pulp_last_updated
end

#q_selectObject

Filter distributions on the upstream Pulp using complex filtering. E.g. pulp_label_select="foo" OR pulp_label_select="key=val"



73
74
75
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 73

def q_select
  @q_select
end

#sock_connect_timeoutObject

aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



64
65
66
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 64

def sock_connect_timeout
  @sock_connect_timeout
end

#sock_read_timeoutObject

aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



67
68
69
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 67

def sock_read_timeout
  @sock_read_timeout
end

#tls_validationObject

If True, TLS peer validation must be performed.



49
50
51
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 49

def tls_validation
  @tls_validation
end

#total_timeoutObject

aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.



58
59
60
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 58

def total_timeout
  @total_timeout
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 458

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpcoreClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



131
132
133
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 131

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 104

def self.attribute_map
  {
    :'pulp_href' => :'pulp_href',
    :'prn' => :'prn',
    :'pulp_created' => :'pulp_created',
    :'pulp_last_updated' => :'pulp_last_updated',
    :'name' => :'name',
    :'base_url' => :'base_url',
    :'api_root' => :'api_root',
    :'domain' => :'domain',
    :'ca_cert' => :'ca_cert',
    :'client_cert' => :'client_cert',
    :'tls_validation' => :'tls_validation',
    :'download_concurrency' => :'download_concurrency',
    :'max_retries' => :'max_retries',
    :'total_timeout' => :'total_timeout',
    :'connect_timeout' => :'connect_timeout',
    :'sock_connect_timeout' => :'sock_connect_timeout',
    :'sock_read_timeout' => :'sock_read_timeout',
    :'hidden_fields' => :'hidden_fields',
    :'q_select' => :'q_select',
    :'last_replication' => :'last_replication',
    :'policy' => :'policy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 434

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 163

def self.openapi_nullable
  Set.new([
    :'domain',
    :'ca_cert',
    :'client_cert',
    :'download_concurrency',
    :'max_retries',
    :'total_timeout',
    :'connect_timeout',
    :'sock_connect_timeout',
    :'sock_read_timeout',
    :'q_select',
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 136

def self.openapi_types
  {
    :'pulp_href' => :'String',
    :'prn' => :'String',
    :'pulp_created' => :'Time',
    :'pulp_last_updated' => :'Time',
    :'name' => :'String',
    :'base_url' => :'String',
    :'api_root' => :'String',
    :'domain' => :'String',
    :'ca_cert' => :'String',
    :'client_cert' => :'String',
    :'tls_validation' => :'Boolean',
    :'download_concurrency' => :'Integer',
    :'max_retries' => :'Integer',
    :'total_timeout' => :'Float',
    :'connect_timeout' => :'Float',
    :'sock_connect_timeout' => :'Float',
    :'sock_read_timeout' => :'Float',
    :'hidden_fields' => :'Array<GenericRemoteResponseHiddenFieldsInner>',
    :'q_select' => :'String',
    :'last_replication' => :'Time',
    :'policy' => :'Policy357Enum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 393

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_href == o.pulp_href &&
      prn == o.prn &&
      pulp_created == o.pulp_created &&
      pulp_last_updated == o.pulp_last_updated &&
      name == o.name &&
      base_url == o.base_url &&
      api_root == o.api_root &&
      domain == o.domain &&
      ca_cert == o.ca_cert &&
      client_cert == o.client_cert &&
      tls_validation == o.tls_validation &&
      download_concurrency == o.download_concurrency &&
      max_retries == o.max_retries &&
      total_timeout == o.total_timeout &&
      connect_timeout == o.connect_timeout &&
      sock_connect_timeout == o.sock_connect_timeout &&
      sock_read_timeout == o.sock_read_timeout &&
      hidden_fields == o.hidden_fields &&
      q_select == o.q_select &&
      last_replication == o.last_replication &&
      policy == o.policy
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 529

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


421
422
423
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 421

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



427
428
429
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 427

def hash
  [pulp_href, prn, pulp_created, pulp_last_updated, name, base_url, api_root, domain, ca_cert, client_cert, tls_validation, download_concurrency, max_retries, total_timeout, connect_timeout, sock_connect_timeout, sock_read_timeout, hidden_fields, q_select, last_replication, policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 288

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @base_url.nil?
    invalid_properties.push('invalid value for "base_url", base_url cannot be nil.')
  end

  if @api_root.nil?
    invalid_properties.push('invalid value for "api_root", api_root cannot be nil.')
  end

  if !@download_concurrency.nil? && @download_concurrency < 1
    invalid_properties.push('invalid value for "download_concurrency", must be greater than or equal to 1.')
  end

  if !@total_timeout.nil? && @total_timeout < 0.0
    invalid_properties.push('invalid value for "total_timeout", must be greater than or equal to 0.0.')
  end

  if !@connect_timeout.nil? && @connect_timeout < 0.0
    invalid_properties.push('invalid value for "connect_timeout", must be greater than or equal to 0.0.')
  end

  if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0
    invalid_properties.push('invalid value for "sock_connect_timeout", must be greater than or equal to 0.0.')
  end

  if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0
    invalid_properties.push('invalid value for "sock_read_timeout", must be greater than or equal to 0.0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



505
506
507
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 505

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
514
515
516
517
518
519
520
521
522
523
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 511

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



499
500
501
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 499

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 328

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @base_url.nil?
  return false if @api_root.nil?
  return false if !@download_concurrency.nil? && @download_concurrency < 1
  return false if !@total_timeout.nil? && @total_timeout < 0.0
  return false if !@connect_timeout.nil? && @connect_timeout < 0.0
  return false if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0
  return false if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0
  true
end