Class: PulpcoreClient::UpstreamPulpsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/api/upstream_pulps_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UpstreamPulpsApi



19
20
21
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_role(upstream_pulp_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Add a role Add a role for this object to users/groups.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



29
30
31
32
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 29

def add_role(upstream_pulp_href, nested_role, opts = {})
  data, _status_code, _headers = add_role_with_http_info(upstream_pulp_href, nested_role, opts)
  data
end

#add_role_with_http_info(upstream_pulp_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Add a role Add a role for this object to users/groups.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 41

def add_role_with_http_info(upstream_pulp_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.add_role ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.add_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling UpstreamPulpsApi.add_role"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}add_role/'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create(upstream_pulp, opts = {}) ⇒ UpstreamPulpResponse

Create an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



101
102
103
104
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 101

def create(upstream_pulp, opts = {})
  data, _status_code, _headers = create_with_http_info(upstream_pulp, opts)
  data
end

#create_with_http_info(upstream_pulp, opts = {}) ⇒ Array<(UpstreamPulpResponse, Integer, Hash)>

Create an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 112

def create_with_http_info(upstream_pulp, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.create ...'
  end
  # verify the required parameter 'upstream_pulp' is set
  if @api_client.config.client_side_validation && upstream_pulp.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp' when calling UpstreamPulpsApi.create"
  end
  # resource path
  local_var_path = '/pulp/api/v3/upstream-pulps/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(upstream_pulp) 

  # return_type
  return_type = opts[:return_type] || 'UpstreamPulpResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(upstream_pulp_href, opts = {}) ⇒ nil

Delete an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



168
169
170
171
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 168

def delete(upstream_pulp_href, opts = {})
  delete_with_http_info(upstream_pulp_href, opts)
  nil
end

#delete_with_http_info(upstream_pulp_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 179

def delete_with_http_info(upstream_pulp_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.delete ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.delete"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(opts = {}) ⇒ PaginatedUpstreamPulpResponseList

List upstream pulps API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



234
235
236
237
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 234

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end

#list_roles(upstream_pulp_href, opts = {}) ⇒ ObjectRolesResponse

List roles List roles assigned to this object.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



304
305
306
307
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 304

def list_roles(upstream_pulp_href, opts = {})
  data, _status_code, _headers = list_roles_with_http_info(upstream_pulp_href, opts)
  data
end

#list_roles_with_http_info(upstream_pulp_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>

List roles List roles assigned to this object.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 317

def list_roles_with_http_info(upstream_pulp_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.list_roles ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.list_roles"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}list_roles/'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'ObjectRolesResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_with_http_info(opts = {}) ⇒ Array<(PaginatedUpstreamPulpResponseList, Integer, Hash)>

List upstream pulps API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 248

def list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.list ...'
  end
  # resource path
  local_var_path = '/pulp/api/v3/upstream-pulps/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'PaginatedUpstreamPulpResponseList' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#my_permissions(upstream_pulp_href, opts = {}) ⇒ MyPermissionsResponse

List user permissions List permissions available to the current user on this object.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



375
376
377
378
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 375

def my_permissions(upstream_pulp_href, opts = {})
  data, _status_code, _headers = my_permissions_with_http_info(upstream_pulp_href, opts)
  data
end

#my_permissions_with_http_info(upstream_pulp_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>

List user permissions List permissions available to the current user on this object.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 388

def my_permissions_with_http_info(upstream_pulp_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.my_permissions ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.my_permissions"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}my_permissions/'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'MyPermissionsResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#partial_update(upstream_pulp_href, patched_upstream_pulp, opts = {}) ⇒ UpstreamPulpResponse

Update an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



445
446
447
448
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 445

def partial_update(upstream_pulp_href, patched_upstream_pulp, opts = {})
  data, _status_code, _headers = partial_update_with_http_info(upstream_pulp_href, patched_upstream_pulp, opts)
  data
end

#partial_update_with_http_info(upstream_pulp_href, patched_upstream_pulp, opts = {}) ⇒ Array<(UpstreamPulpResponse, Integer, Hash)>

Update an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 457

def partial_update_with_http_info(upstream_pulp_href, patched_upstream_pulp, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.partial_update ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.partial_update"
  end
  # verify the required parameter 'patched_upstream_pulp' is set
  if @api_client.config.client_side_validation && patched_upstream_pulp.nil?
    fail ArgumentError, "Missing the required parameter 'patched_upstream_pulp' when calling UpstreamPulpsApi.partial_update"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(patched_upstream_pulp) 

  # return_type
  return_type = opts[:return_type] || 'UpstreamPulpResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(upstream_pulp_href, opts = {}) ⇒ UpstreamPulpResponse

Inspect an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



519
520
521
522
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 519

def read(upstream_pulp_href, opts = {})
  data, _status_code, _headers = read_with_http_info(upstream_pulp_href, opts)
  data
end

#read_with_http_info(upstream_pulp_href, opts = {}) ⇒ Array<(UpstreamPulpResponse, Integer, Hash)>

Inspect an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 532

def read_with_http_info(upstream_pulp_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.read ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.read"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'UpstreamPulpResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_role(upstream_pulp_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Remove a role Remove a role for this object from users/groups.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



589
590
591
592
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 589

def remove_role(upstream_pulp_href, nested_role, opts = {})
  data, _status_code, _headers = remove_role_with_http_info(upstream_pulp_href, nested_role, opts)
  data
end

#remove_role_with_http_info(upstream_pulp_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Remove a role Remove a role for this object from users/groups.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 601

def remove_role_with_http_info(upstream_pulp_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.remove_role ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.remove_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling UpstreamPulpsApi.remove_role"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}remove_role/'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#replicate(upstream_pulp_href, opts = {}) ⇒ TaskGroupOperationResponse

Replicate Trigger an asynchronous repository replication task group. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



661
662
663
664
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 661

def replicate(upstream_pulp_href, opts = {})
  data, _status_code, _headers = replicate_with_http_info(upstream_pulp_href, opts)
  data
end

#replicate_with_http_info(upstream_pulp_href, opts = {}) ⇒ Array<(TaskGroupOperationResponse, Integer, Hash)>

Replicate Trigger an asynchronous repository replication task group. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 672

def replicate_with_http_info(upstream_pulp_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.replicate ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.replicate"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}replicate/'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TaskGroupOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#replicate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update(upstream_pulp_href, upstream_pulp, opts = {}) ⇒ UpstreamPulpResponse

Update an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



727
728
729
730
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 727

def update(upstream_pulp_href, upstream_pulp, opts = {})
  data, _status_code, _headers = update_with_http_info(upstream_pulp_href, upstream_pulp, opts)
  data
end

#update_with_http_info(upstream_pulp_href, upstream_pulp, opts = {}) ⇒ Array<(UpstreamPulpResponse, Integer, Hash)>

Update an upstream pulp API for configuring an upstream Pulp to replicate. This API is provided as a tech preview.

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.



739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/pulpcore_client/api/upstream_pulps_api.rb', line 739

def update_with_http_info(upstream_pulp_href, upstream_pulp, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UpstreamPulpsApi.update ...'
  end
  # verify the required parameter 'upstream_pulp_href' is set
  if @api_client.config.client_side_validation && upstream_pulp_href.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp_href' when calling UpstreamPulpsApi.update"
  end
  # verify the required parameter 'upstream_pulp' is set
  if @api_client.config.client_side_validation && upstream_pulp.nil?
    fail ArgumentError, "Missing the required parameter 'upstream_pulp' when calling UpstreamPulpsApi.update"
  end
  # resource path
  local_var_path = '{upstream_pulp_href}'.sub('{' + 'upstream_pulp_href' + '}', CGI.escape(upstream_pulp_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(upstream_pulp) 

  # return_type
  return_type = opts[:return_type] || 'UpstreamPulpResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UpstreamPulpsApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end