Method: PulpcoreClient::AccessPoliciesApi#list
- Defined in:
- lib/pulpcore_client/api/access_policies_api.rb
#list(opts = {}) ⇒ PaginatedAccessPolicyResponseList
List access policys ViewSet for AccessPolicy.
Parameters:
-
opts
(Hash)
(defaults to: {})
—
the optional parameters
Options Hash (opts):
-
:customized
(Boolean)
—
Filter results where customized matches value
-
:limit
(Integer)
—
Number of results to return per page.
-
:offset
(Integer)
—
The initial index from which to return the results.
-
:ordering
(Array<String>)
—
Ordering * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `creation_hooks` - Creation hooks * `-creation_hooks` - Creation hooks (descending) * `statements` - Statements * `-statements` - Statements (descending) * `viewset_name` - Viewset name * `-viewset_name` - Viewset name (descending) * `customized` - Customized * `-customized` - Customized (descending) * `queryset_scoping` - Queryset scoping * `-queryset_scoping` - Queryset scoping (descending) * `pk` - Pk * `-pk` - Pk (descending)
-
:prn__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_href__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_id__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:q
(String)
—
Filter results by using NOT, AND and OR operations on other filters
-
:viewset_name
(String)
—
Filter results where viewset_name matches value
-
:viewset_name__contains
(String)
—
Filter results where viewset_name contains value
-
:viewset_name__icontains
(String)
—
Filter results where viewset_name contains value
-
:viewset_name__iexact
(String)
—
Filter results where viewset_name matches value
-
:viewset_name__in
(Array<String>)
—
Filter results where viewset_name is in a comma-separated list of values
-
:viewset_name__iregex
(String)
—
Filter results where viewset_name matches regex value
-
:viewset_name__istartswith
(String)
—
Filter results where viewset_name starts with value
-
:viewset_name__regex
(String)
—
Filter results where viewset_name matches regex value
-
:viewset_name__startswith
(String)
—
Filter results where viewset_name starts with value
-
:fields
(Array<String>)
—
A list of fields to include in the response.
-
:exclude_fields
(Array<String>)
—
A list of fields to exclude from the response.
Returns:
45 46 47 48 |
# File 'lib/pulpcore_client/api/access_policies_api.rb', line 45 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |