Method: PulpcoreClient::DistributionsArtifactsApi#list
- Defined in:
- lib/pulpcore_client/api/distributions_artifacts_api.rb
#list(opts = {}) ⇒ PaginatedArtifactDistributionResponseList
List artifact distributions ViewSet for ArtifactDistribution.
Parameters:
-
opts
(Hash)
(defaults to: {})
—
the optional parameters
Options Hash (opts):
-
:base_path
(String)
—
Filter results where base_path matches value
-
:base_path__contains
(String)
—
Filter results where base_path contains value
-
:base_path__icontains
(String)
—
Filter results where base_path contains value
-
:base_path__in
(Array<String>)
—
Filter results where base_path is in a comma-separated list of values
-
:checkpoint
(Boolean)
—
Filter results where checkpoint matches value
-
:limit
(Integer)
—
Number of results to return per page.
-
:name
(String)
—
Filter results where name matches value
-
:name__contains
(String)
—
Filter results where name contains value
-
:name__icontains
(String)
—
Filter results where name contains value
-
:name__iexact
(String)
—
Filter results where name matches value
-
:name__in
(Array<String>)
—
Filter results where name is in a comma-separated list of values
-
:name__iregex
(String)
—
Filter results where name matches regex value
-
:name__istartswith
(String)
—
Filter results where name starts with value
-
:name__regex
(String)
—
Filter results where name matches regex value
-
:name__startswith
(String)
—
Filter results where name starts with value
-
:offset
(Integer)
—
The initial index from which to return the results.
-
:ordering
(Array<String>)
—
Ordering * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `name` - Name * `-name` - Name (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `base_path` - Base path * `-base_path` - Base path (descending) * `hidden` - Hidden * `-hidden` - Hidden (descending) * `checkpoint` - Checkpoint * `-checkpoint` - Checkpoint (descending) * `pk` - Pk * `-pk` - Pk (descending)
-
:prn__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_href__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_id__in
(Array<String>)
—
Multiple values may be separated by commas.
-
:pulp_label_select
(String)
—
Filter labels by search string
-
:q
(String)
—
Filter results by using NOT, AND and OR operations on other filters
-
:repository
(String)
—
Filter results where repository matches value
-
:repository__in
(Array<String>)
—
Filter results where repository is in a comma-separated list of values
-
:with_content
(String)
—
Filter distributions based on the content served by them
-
:fields
(Array<String>)
—
A list of fields to include in the response.
-
:exclude_fields
(Array<String>)
—
A list of fields to exclude from the response.
Returns:
53 54 55 56 |
# File 'lib/pulpcore_client/api/distributions_artifacts_api.rb', line 53 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |