Method: PulpcoreClient::PatchedPulpExporter#list_invalid_properties
- Defined in:
- lib/pulpcore_client/models/patched_pulp_exporter.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/pulpcore_client/models/patched_pulp_exporter.rb', line 98 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@path.nil? && @path.to_s.length < 1 invalid_properties.push('invalid value for "path", the character length must be great than or equal to 1.') end invalid_properties end |