Class: PulpcoreClient::TasksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/api/tasks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TasksApi

Returns a new instance of TasksApi.



19
20
21
# File 'lib/pulpcore_client/api/tasks_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulpcore_client/api/tasks_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Add a role Add a role for this object to users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



29
30
31
32
# File 'lib/pulpcore_client/api/tasks_api.rb', line 29

def add_role(task_href, nested_role, opts = {})
  data, _status_code, _headers = add_role_with_http_info(task_href, nested_role, opts)
  data
end

#add_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Add a role Add a role for this object to users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(NestedRoleResponse, Integer, Hash)>)

    NestedRoleResponse data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/pulpcore_client/api/tasks_api.rb', line 41

def add_role_with_http_info(task_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.add_role ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.add_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling TasksApi.add_role"
  end
  # resource path
  local_var_path = '{task_href}add_role/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(task_href, opts = {}) ⇒ nil

Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (nil)


101
102
103
104
# File 'lib/pulpcore_client/api/tasks_api.rb', line 101

def delete(task_href, opts = {})
  delete_with_http_info(task_href, opts)
  nil
end

#delete_with_http_info(task_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. &quot;Normal&quot; Django Models and Master/Detail models are supported by the ``register_with`` method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the &quot;parent_prefix&quot; of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/pulpcore_client/api/tasks_api.rb', line 112

def delete_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.delete ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.delete"
  end
  # resource path
  local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(opts = {}) ⇒ PaginatedTaskResponseList

List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :child_tasks (String)

    Filter results where child_tasks matches value

  • :created_resources (String)
  • :exclusive_resources (String)
  • :exclusive_resources__in (Array<String>)

    Multiple values may be separated by commas.

  • :finished_at (DateTime)

    Filter results where finished_at matches value

  • :finished_at__gt (DateTime)

    Filter results where finished_at is greater than value

  • :finished_at__gte (DateTime)

    Filter results where finished_at is greater than or equal to value

  • :finished_at__lt (DateTime)

    Filter results where finished_at is less than value

  • :finished_at__lte (DateTime)

    Filter results where finished_at is less than or equal to value

  • :finished_at__range (Array<DateTime>)

    Filter results where finished_at is between two comma separated values

  • :limit (Integer)

    Number of results to return per page.

  • :logging_cid (String)

    Filter results where logging_cid matches value

  • :logging_cid__contains (String)

    Filter results where logging_cid contains value

  • :name (String)

    Filter results where name matches value

  • :name__contains (String)

    Filter results where name contains value

  • :name__in (Array<String>)

    Filter results where name is in a comma-separated list of values

  • :name__ne (String)

    Filter results where name not equal to value

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `state` - State * `-state` - State (descending) * `name` - Name * `-name` - Name (descending) * `logging_cid` - Logging cid * `-logging_cid` - Logging cid (descending) * `unblocked_at` - Unblocked at * `-unblocked_at` - Unblocked at (descending) * `started_at` - Started at * `-started_at` - Started at (descending) * `finished_at` - Finished at * `-finished_at` - Finished at (descending) * `error` - Error * `-error` - Error (descending) * `enc_args` - Enc args * `-enc_args` - Enc args (descending) * `enc_kwargs` - Enc kwargs * `-enc_kwargs` - Enc kwargs (descending) * `reserved_resources_record` - Reserved resources record * `-reserved_resources_record` - Reserved resources record (descending) * `versions` - Versions * `-versions` - Versions (descending) * `pk` - Pk * `-pk` - Pk (descending)

  • :parent_task (String)

    Filter results where parent_task matches value

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :q (String)
  • :reserved_resources (String)
  • :reserved_resources__in (Array<String>)

    Multiple values may be separated by commas.

  • :reserved_resources_record (Array<String>)
  • :shared_resources (String)
  • :shared_resources__in (Array<String>)

    Multiple values may be separated by commas.

  • :started_at (DateTime)

    Filter results where started_at matches value

  • :started_at__gt (DateTime)

    Filter results where started_at is greater than value

  • :started_at__gte (DateTime)

    Filter results where started_at is greater than or equal to value

  • :started_at__lt (DateTime)

    Filter results where started_at is less than value

  • :started_at__lte (DateTime)

    Filter results where started_at is less than or equal to value

  • :started_at__range (Array<DateTime>)

    Filter results where started_at is between two comma separated values

  • :state (String)

    Filter results where state matches value * `waiting` - Waiting * `skipped` - Skipped * `running` - Running * `completed` - Completed * `failed` - Failed * `canceled` - Canceled * `canceling` - Canceling

  • :state__in (Array<String>)

    Filter results where state is in a comma-separated list of values

  • :state__ne (String)

    Filter results where state not equal to value

  • :task_group (String)

    Filter results where task_group matches value

  • :worker (String)

    Filter results where worker matches value

  • :worker__in (Array<String>)

    Filter results where worker is in a comma-separated list of values

  • :worker__isnull (Boolean)

    Filter results where worker has a null value

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



206
207
208
209
# File 'lib/pulpcore_client/api/tasks_api.rb', line 206

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end

#list_roles(task_href, opts = {}) ⇒ ObjectRolesResponse

List roles List roles assigned to this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



362
363
364
365
# File 'lib/pulpcore_client/api/tasks_api.rb', line 362

def list_roles(task_href, opts = {})
  data, _status_code, _headers = list_roles_with_http_info(task_href, opts)
  data
end

#list_roles_with_http_info(task_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>

List roles List roles assigned to this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(ObjectRolesResponse, Integer, Hash)>)

    ObjectRolesResponse data, response status code and response headers



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/pulpcore_client/api/tasks_api.rb', line 375

def list_roles_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.list_roles ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.list_roles"
  end
  # resource path
  local_var_path = '{task_href}list_roles/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'ObjectRolesResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_with_http_info(opts = {}) ⇒ Array<(PaginatedTaskResponseList, Integer, Hash)>

List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. &quot;Normal&quot; Django Models and Master/Detail models are supported by the ``register_with`` method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the &quot;parent_prefix&quot; of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :child_tasks (String)

    Filter results where child_tasks matches value

  • :created_resources (String)
  • :exclusive_resources (String)
  • :exclusive_resources__in (Array<String>)

    Multiple values may be separated by commas.

  • :finished_at (DateTime)

    Filter results where finished_at matches value

  • :finished_at__gt (DateTime)

    Filter results where finished_at is greater than value

  • :finished_at__gte (DateTime)

    Filter results where finished_at is greater than or equal to value

  • :finished_at__lt (DateTime)

    Filter results where finished_at is less than value

  • :finished_at__lte (DateTime)

    Filter results where finished_at is less than or equal to value

  • :finished_at__range (Array<DateTime>)

    Filter results where finished_at is between two comma separated values

  • :limit (Integer)

    Number of results to return per page.

  • :logging_cid (String)

    Filter results where logging_cid matches value

  • :logging_cid__contains (String)

    Filter results where logging_cid contains value

  • :name (String)

    Filter results where name matches value

  • :name__contains (String)

    Filter results where name contains value

  • :name__in (Array<String>)

    Filter results where name is in a comma-separated list of values

  • :name__ne (String)

    Filter results where name not equal to value

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `state` - State * `-state` - State (descending) * `name` - Name * `-name` - Name (descending) * `logging_cid` - Logging cid * `-logging_cid` - Logging cid (descending) * `unblocked_at` - Unblocked at * `-unblocked_at` - Unblocked at (descending) * `started_at` - Started at * `-started_at` - Started at (descending) * `finished_at` - Finished at * `-finished_at` - Finished at (descending) * `error` - Error * `-error` - Error (descending) * `enc_args` - Enc args * `-enc_args` - Enc args (descending) * `enc_kwargs` - Enc kwargs * `-enc_kwargs` - Enc kwargs (descending) * `reserved_resources_record` - Reserved resources record * `-reserved_resources_record` - Reserved resources record (descending) * `versions` - Versions * `-versions` - Versions (descending) * `pk` - Pk * `-pk` - Pk (descending)

  • :parent_task (String)

    Filter results where parent_task matches value

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :q (String)
  • :reserved_resources (String)
  • :reserved_resources__in (Array<String>)

    Multiple values may be separated by commas.

  • :reserved_resources_record (Array<String>)
  • :shared_resources (String)
  • :shared_resources__in (Array<String>)

    Multiple values may be separated by commas.

  • :started_at (DateTime)

    Filter results where started_at matches value

  • :started_at__gt (DateTime)

    Filter results where started_at is greater than value

  • :started_at__gte (DateTime)

    Filter results where started_at is greater than or equal to value

  • :started_at__lt (DateTime)

    Filter results where started_at is less than value

  • :started_at__lte (DateTime)

    Filter results where started_at is less than or equal to value

  • :started_at__range (Array<DateTime>)

    Filter results where started_at is between two comma separated values

  • :state (String)

    Filter results where state matches value * `waiting` - Waiting * `skipped` - Skipped * `running` - Running * `completed` - Completed * `failed` - Failed * `canceled` - Canceled * `canceling` - Canceling

  • :state__in (Array<String>)

    Filter results where state is in a comma-separated list of values

  • :state__ne (String)

    Filter results where state not equal to value

  • :task_group (String)

    Filter results where task_group matches value

  • :worker (String)

    Filter results where worker matches value

  • :worker__in (Array<String>)

    Filter results where worker is in a comma-separated list of values

  • :worker__isnull (Boolean)

    Filter results where worker has a null value

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(PaginatedTaskResponseList, Integer, Hash)>)

    PaginatedTaskResponseList data, response status code and response headers



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/pulpcore_client/api/tasks_api.rb', line 259

def list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.list ...'
  end
  allowable_values = ["-enc_args", "-enc_kwargs", "-error", "-finished_at", "-logging_cid", "-name", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-reserved_resources_record", "-started_at", "-state", "-unblocked_at", "-versions", "enc_args", "enc_kwargs", "error", "finished_at", "logging_cid", "name", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "reserved_resources_record", "started_at", "state", "unblocked_at", "versions"]
  if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}"
  end
  allowable_values = ["canceled", "canceling", "completed", "failed", "running", "skipped", "waiting"]
  if @api_client.config.client_side_validation && opts[:'state'] && !allowable_values.include?(opts[:'state'])
    fail ArgumentError, "invalid value for \"state\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/pulp/api/v3/tasks/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'child_tasks'] = opts[:'child_tasks'] if !opts[:'child_tasks'].nil?
  query_params[:'created_resources'] = opts[:'created_resources'] if !opts[:'created_resources'].nil?
  query_params[:'exclusive_resources'] = opts[:'exclusive_resources'] if !opts[:'exclusive_resources'].nil?
  query_params[:'exclusive_resources__in'] = @api_client.build_collection_param(opts[:'exclusive_resources__in'], :csv) if !opts[:'exclusive_resources__in'].nil?
  query_params[:'finished_at'] = opts[:'finished_at'] if !opts[:'finished_at'].nil?
  query_params[:'finished_at__gt'] = opts[:'finished_at__gt'] if !opts[:'finished_at__gt'].nil?
  query_params[:'finished_at__gte'] = opts[:'finished_at__gte'] if !opts[:'finished_at__gte'].nil?
  query_params[:'finished_at__lt'] = opts[:'finished_at__lt'] if !opts[:'finished_at__lt'].nil?
  query_params[:'finished_at__lte'] = opts[:'finished_at__lte'] if !opts[:'finished_at__lte'].nil?
  query_params[:'finished_at__range'] = @api_client.build_collection_param(opts[:'finished_at__range'], :csv) if !opts[:'finished_at__range'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'logging_cid'] = opts[:'logging_cid'] if !opts[:'logging_cid'].nil?
  query_params[:'logging_cid__contains'] = opts[:'logging_cid__contains'] if !opts[:'logging_cid__contains'].nil?
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil?
  query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil?
  query_params[:'name__ne'] = opts[:'name__ne'] if !opts[:'name__ne'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil?
  query_params[:'parent_task'] = opts[:'parent_task'] if !opts[:'parent_task'].nil?
  query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil?
  query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'reserved_resources'] = opts[:'reserved_resources'] if !opts[:'reserved_resources'].nil?
  query_params[:'reserved_resources__in'] = @api_client.build_collection_param(opts[:'reserved_resources__in'], :csv) if !opts[:'reserved_resources__in'].nil?
  query_params[:'reserved_resources_record'] = @api_client.build_collection_param(opts[:'reserved_resources_record'], :multi) if !opts[:'reserved_resources_record'].nil?
  query_params[:'shared_resources'] = opts[:'shared_resources'] if !opts[:'shared_resources'].nil?
  query_params[:'shared_resources__in'] = @api_client.build_collection_param(opts[:'shared_resources__in'], :csv) if !opts[:'shared_resources__in'].nil?
  query_params[:'started_at'] = opts[:'started_at'] if !opts[:'started_at'].nil?
  query_params[:'started_at__gt'] = opts[:'started_at__gt'] if !opts[:'started_at__gt'].nil?
  query_params[:'started_at__gte'] = opts[:'started_at__gte'] if !opts[:'started_at__gte'].nil?
  query_params[:'started_at__lt'] = opts[:'started_at__lt'] if !opts[:'started_at__lt'].nil?
  query_params[:'started_at__lte'] = opts[:'started_at__lte'] if !opts[:'started_at__lte'].nil?
  query_params[:'started_at__range'] = @api_client.build_collection_param(opts[:'started_at__range'], :csv) if !opts[:'started_at__range'].nil?
  query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil?
  query_params[:'state__in'] = @api_client.build_collection_param(opts[:'state__in'], :csv) if !opts[:'state__in'].nil?
  query_params[:'state__ne'] = opts[:'state__ne'] if !opts[:'state__ne'].nil?
  query_params[:'task_group'] = opts[:'task_group'] if !opts[:'task_group'].nil?
  query_params[:'worker'] = opts[:'worker'] if !opts[:'worker'].nil?
  query_params[:'worker__in'] = @api_client.build_collection_param(opts[:'worker__in'], :csv) if !opts[:'worker__in'].nil?
  query_params[:'worker__isnull'] = opts[:'worker__isnull'] if !opts[:'worker__isnull'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'PaginatedTaskResponseList' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#my_permissions(task_href, opts = {}) ⇒ MyPermissionsResponse

List user permissions List permissions available to the current user on this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



433
434
435
436
# File 'lib/pulpcore_client/api/tasks_api.rb', line 433

def my_permissions(task_href, opts = {})
  data, _status_code, _headers = my_permissions_with_http_info(task_href, opts)
  data
end

#my_permissions_with_http_info(task_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>

List user permissions List permissions available to the current user on this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(MyPermissionsResponse, Integer, Hash)>)

    MyPermissionsResponse data, response status code and response headers



446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/pulpcore_client/api/tasks_api.rb', line 446

def my_permissions_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.my_permissions ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.my_permissions"
  end
  # resource path
  local_var_path = '{task_href}my_permissions/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'MyPermissionsResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#purge(purge, opts = {}) ⇒ AsyncOperationResponse

Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp.

Parameters:

  • purge (Purge)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



502
503
504
505
# File 'lib/pulpcore_client/api/tasks_api.rb', line 502

def purge(purge, opts = {})
  data, _status_code, _headers = purge_with_http_info(purge, opts)
  data
end

#purge_with_http_info(purge, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp.

Parameters:

  • purge (Purge)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(AsyncOperationResponse, Integer, Hash)>)

    AsyncOperationResponse data, response status code and response headers



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/pulpcore_client/api/tasks_api.rb', line 513

def purge_with_http_info(purge, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.purge ...'
  end
  # verify the required parameter 'purge' is set
  if @api_client.config.client_side_validation && purge.nil?
    fail ArgumentError, "Missing the required parameter 'purge' when calling TasksApi.purge"
  end
  # resource path
  local_var_path = '/pulp/api/v3/tasks/purge/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(purge) 

  # return_type
  return_type = opts[:return_type] || 'AsyncOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#purge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(task_href, opts = {}) ⇒ TaskResponse

Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. "Normal" Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the "parent_prefix" of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



571
572
573
574
# File 'lib/pulpcore_client/api/tasks_api.rb', line 571

def read(task_href, opts = {})
  data, _status_code, _headers = read_with_http_info(task_href, opts)
  data
end

#read_with_http_info(task_href, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>

Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. &quot;Normal&quot; Django Models and Master/Detail models are supported by the ``register_with`` method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to 'pk' endpoint_name (str): The name of the final path segment that should identify the ViewSet's collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the &quot;parent_prefix&quot; of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object's identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(TaskResponse, Integer, Hash)>)

    TaskResponse data, response status code and response headers



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
# File 'lib/pulpcore_client/api/tasks_api.rb', line 584

def read_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.read ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.read"
  end
  # resource path
  local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TaskResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Remove a role Remove a role for this object from users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



641
642
643
644
# File 'lib/pulpcore_client/api/tasks_api.rb', line 641

def remove_role(task_href, nested_role, opts = {})
  data, _status_code, _headers = remove_role_with_http_info(task_href, nested_role, opts)
  data
end

#remove_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Remove a role Remove a role for this object from users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(NestedRoleResponse, Integer, Hash)>)

    NestedRoleResponse data, response status code and response headers



653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
# File 'lib/pulpcore_client/api/tasks_api.rb', line 653

def remove_role_with_http_info(task_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.remove_role ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.remove_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling TasksApi.remove_role"
  end
  # resource path
  local_var_path = '{task_href}remove_role/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_cancel(task_href, patched_task_cancel, opts = {}) ⇒ TaskResponse

Cancel a task This operation cancels a task.

Parameters:

  • task_href (String)
  • patched_task_cancel (PatchedTaskCancel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:



714
715
716
717
# File 'lib/pulpcore_client/api/tasks_api.rb', line 714

def tasks_cancel(task_href, patched_task_cancel, opts = {})
  data, _status_code, _headers = tasks_cancel_with_http_info(task_href, patched_task_cancel, opts)
  data
end

#tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>

Cancel a task This operation cancels a task.

Parameters:

  • task_href (String)
  • patched_task_cancel (PatchedTaskCancel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_task_diagnostics (Array<String>)

    List of profilers to use on tasks.

Returns:

  • (Array<(TaskResponse, Integer, Hash)>)

    TaskResponse data, response status code and response headers



726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
# File 'lib/pulpcore_client/api/tasks_api.rb', line 726

def tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_cancel ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_cancel"
  end
  # verify the required parameter 'patched_task_cancel' is set
  if @api_client.config.client_side_validation && patched_task_cancel.nil?
    fail ArgumentError, "Missing the required parameter 'patched_task_cancel' when calling TasksApi.tasks_cancel"
  end
  # resource path
  local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(patched_task_cancel) 

  # return_type
  return_type = opts[:return_type] || 'TaskResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end