Class: PulpcoreClient::TasksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulpcore_client/api/tasks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TasksApi

Returns a new instance of TasksApi.



19
20
21
# File 'lib/pulpcore_client/api/tasks_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulpcore_client/api/tasks_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#tasks_add_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Add a role for this object to users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/pulpcore_client/api/tasks_api.rb', line 27

def tasks_add_role(task_href, nested_role, opts = {})
  data, _status_code, _headers = tasks_add_role_with_http_info(task_href, nested_role, opts)
  data
end

#tasks_add_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Add a role for this object to users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(NestedRoleResponse, Integer, Hash)>)

    NestedRoleResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/pulpcore_client/api/tasks_api.rb', line 37

def tasks_add_role_with_http_info(task_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_add_role ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_add_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling TasksApi.tasks_add_role"
  end
  # resource path
  local_var_path = '{task_href}add_role/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_cancel(task_href, patched_task_cancel, opts = {}) ⇒ TaskResponse

Cancel a task This operation cancels a task.

Parameters:

  • task_href (String)
  • patched_task_cancel (PatchedTaskCancel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



96
97
98
99
# File 'lib/pulpcore_client/api/tasks_api.rb', line 96

def tasks_cancel(task_href, patched_task_cancel, opts = {})
  data, _status_code, _headers = tasks_cancel_with_http_info(task_href, patched_task_cancel, opts)
  data
end

#tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>

Cancel a task This operation cancels a task.

Parameters:

  • task_href (String)
  • patched_task_cancel (PatchedTaskCancel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TaskResponse, Integer, Hash)>)

    TaskResponse data, response status code and response headers



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/pulpcore_client/api/tasks_api.rb', line 107

def tasks_cancel_with_http_info(task_href, patched_task_cancel, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_cancel ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_cancel"
  end
  # verify the required parameter 'patched_task_cancel' is set
  if @api_client.config.client_side_validation && patched_task_cancel.nil?
    fail ArgumentError, "Missing the required parameter 'patched_task_cancel' when calling TasksApi.tasks_cancel"
  end
  # resource path
  local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(patched_task_cancel) 

  # return_type
  return_type = opts[:return_type] || 'TaskResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_cancel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_delete(task_href, opts = {}) ⇒ nil

Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. \“Normal\” Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to ‘pk’ endpoint_name (str): The name of the final path segment that should identify the ViewSet’s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the \“parent_prefix\” of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object’s identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


165
166
167
168
# File 'lib/pulpcore_client/api/tasks_api.rb', line 165

def tasks_delete(task_href, opts = {})
  tasks_delete_with_http_info(task_href, opts)
  nil
end

#tasks_delete_with_http_info(task_href, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. \&quot;Normal\&quot; Django Models and Master/Detail models are supported by the &#x60;&#x60;register_with&#x60;&#x60; method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to &#39;pk&#39; endpoint_name (str): The name of the final path segment that should identify the ViewSet&#39;s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the \&quot;parent_prefix\&quot; of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object&#39;s identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/pulpcore_client/api/tasks_api.rb', line 175

def tasks_delete_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_delete ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_delete"
  end
  # resource path
  local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_list(opts = {}) ⇒ PaginatedTaskResponseList

List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. \“Normal\” Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to ‘pk’ endpoint_name (str): The name of the final path segment that should identify the ViewSet’s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the \“parent_prefix\” of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object’s identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :child_tasks (String)

    Foreign Key referenced by HREF

  • :created_resources (String)
  • :finished_at (DateTime)

    ISO 8601 formatted dates are supported

  • :finished_at__gt (DateTime)

    Filter results where finished_at is greater than value

  • :finished_at__gte (DateTime)

    Filter results where finished_at is greater than or equal to value

  • :finished_at__lt (DateTime)

    Filter results where finished_at is less than value

  • :finished_at__lte (DateTime)

    Filter results where finished_at is less than or equal to value

  • :finished_at__range (Array<DateTime>)

    Filter results where finished_at is between two comma separated values

  • :limit (Integer)

    Number of results to return per page.

  • :logging_cid (String)
  • :logging_cid__contains (String)

    Filter results where logging_cid contains value

  • :name (String)
  • :name__contains (String)

    Filter results where name contains value

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering

  • :parent_task (String)

    Foreign Key referenced by HREF

  • :reserved_resources_record (Array<String>)
  • :started_at (DateTime)

    ISO 8601 formatted dates are supported

  • :started_at__gt (DateTime)

    Filter results where started_at is greater than value

  • :started_at__gte (DateTime)

    Filter results where started_at is greater than or equal to value

  • :started_at__lt (DateTime)

    Filter results where started_at is less than value

  • :started_at__lte (DateTime)

    Filter results where started_at is less than or equal to value

  • :started_at__range (Array<DateTime>)

    Filter results where started_at is between two comma separated values

  • :state (String)
  • :state__in (Array<String>)

    Filter results where state is in a comma-separated list of values

  • :task_group (String)

    Foreign Key referenced by HREF

  • :worker (String)

    Foreign Key referenced by HREF

  • :worker__in (Array<String>)

    Filter results where worker is in a comma-separated list of values

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



254
255
256
257
# File 'lib/pulpcore_client/api/tasks_api.rb', line 254

def tasks_list(opts = {})
  data, _status_code, _headers = tasks_list_with_http_info(opts)
  data
end

#tasks_list_roles(task_href, opts = {}) ⇒ ObjectRolesResponse

List roles assigned to this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



380
381
382
383
# File 'lib/pulpcore_client/api/tasks_api.rb', line 380

def tasks_list_roles(task_href, opts = {})
  data, _status_code, _headers = tasks_list_roles_with_http_info(task_href, opts)
  data
end

#tasks_list_roles_with_http_info(task_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>

List roles assigned to this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(ObjectRolesResponse, Integer, Hash)>)

    ObjectRolesResponse data, response status code and response headers



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/pulpcore_client/api/tasks_api.rb', line 391

def tasks_list_roles_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_list_roles ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_list_roles"
  end
  # resource path
  local_var_path = '{task_href}list_roles/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'ObjectRolesResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_list_with_http_info(opts = {}) ⇒ Array<(PaginatedTaskResponseList, Integer, Hash)>

List tasks A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. \&quot;Normal\&quot; Django Models and Master/Detail models are supported by the &#x60;&#x60;register_with&#x60;&#x60; method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to &#39;pk&#39; endpoint_name (str): The name of the final path segment that should identify the ViewSet&#39;s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the \&quot;parent_prefix\&quot; of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object&#39;s identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :child_tasks (String)

    Foreign Key referenced by HREF

  • :created_resources (String)
  • :finished_at (DateTime)

    ISO 8601 formatted dates are supported

  • :finished_at__gt (DateTime)

    Filter results where finished_at is greater than value

  • :finished_at__gte (DateTime)

    Filter results where finished_at is greater than or equal to value

  • :finished_at__lt (DateTime)

    Filter results where finished_at is less than value

  • :finished_at__lte (DateTime)

    Filter results where finished_at is less than or equal to value

  • :finished_at__range (Array<DateTime>)

    Filter results where finished_at is between two comma separated values

  • :limit (Integer)

    Number of results to return per page.

  • :logging_cid (String)
  • :logging_cid__contains (String)

    Filter results where logging_cid contains value

  • :name (String)
  • :name__contains (String)

    Filter results where name contains value

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering

  • :parent_task (String)

    Foreign Key referenced by HREF

  • :reserved_resources_record (Array<String>)
  • :started_at (DateTime)

    ISO 8601 formatted dates are supported

  • :started_at__gt (DateTime)

    Filter results where started_at is greater than value

  • :started_at__gte (DateTime)

    Filter results where started_at is greater than or equal to value

  • :started_at__lt (DateTime)

    Filter results where started_at is less than value

  • :started_at__lte (DateTime)

    Filter results where started_at is less than or equal to value

  • :started_at__range (Array<DateTime>)

    Filter results where started_at is between two comma separated values

  • :state (String)
  • :state__in (Array<String>)

    Filter results where state is in a comma-separated list of values

  • :task_group (String)

    Foreign Key referenced by HREF

  • :worker (String)

    Foreign Key referenced by HREF

  • :worker__in (Array<String>)

    Filter results where worker is in a comma-separated list of values

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(PaginatedTaskResponseList, Integer, Hash)>)

    PaginatedTaskResponseList data, response status code and response headers



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/pulpcore_client/api/tasks_api.rb', line 293

def tasks_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_list ...'
  end
  allowable_values = ["-args", "-child_tasks", "-created_resources", "-error", "-export", "-finished_at", "-group_roles", "-import", "-kwargs", "-logging_cid", "-name", "-parent_task", "-pk", "-progress_reports", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-reserved_resources_record", "-started_at", "-state", "-task_group", "-taskschedule", "-user_roles", "-worker", "args", "child_tasks", "created_resources", "error", "export", "finished_at", "group_roles", "import", "kwargs", "logging_cid", "name", "parent_task", "pk", "progress_reports", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "reserved_resources_record", "started_at", "state", "task_group", "taskschedule", "user_roles", "worker"]
  if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}"
  end
  allowable_values = ["canceled", "canceling", "completed", "failed", "running", "skipped", "waiting"]
  if @api_client.config.client_side_validation && opts[:'state'] && !allowable_values.include?(opts[:'state'])
    fail ArgumentError, "invalid value for \"state\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/pulp/api/v3/tasks/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'child_tasks'] = opts[:'child_tasks'] if !opts[:'child_tasks'].nil?
  query_params[:'created_resources'] = opts[:'created_resources'] if !opts[:'created_resources'].nil?
  query_params[:'finished_at'] = opts[:'finished_at'] if !opts[:'finished_at'].nil?
  query_params[:'finished_at__gt'] = opts[:'finished_at__gt'] if !opts[:'finished_at__gt'].nil?
  query_params[:'finished_at__gte'] = opts[:'finished_at__gte'] if !opts[:'finished_at__gte'].nil?
  query_params[:'finished_at__lt'] = opts[:'finished_at__lt'] if !opts[:'finished_at__lt'].nil?
  query_params[:'finished_at__lte'] = opts[:'finished_at__lte'] if !opts[:'finished_at__lte'].nil?
  query_params[:'finished_at__range'] = @api_client.build_collection_param(opts[:'finished_at__range'], :csv) if !opts[:'finished_at__range'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'logging_cid'] = opts[:'logging_cid'] if !opts[:'logging_cid'].nil?
  query_params[:'logging_cid__contains'] = opts[:'logging_cid__contains'] if !opts[:'logging_cid__contains'].nil?
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil?
  query_params[:'parent_task'] = opts[:'parent_task'] if !opts[:'parent_task'].nil?
  query_params[:'reserved_resources_record'] = @api_client.build_collection_param(opts[:'reserved_resources_record'], :multi) if !opts[:'reserved_resources_record'].nil?
  query_params[:'started_at'] = opts[:'started_at'] if !opts[:'started_at'].nil?
  query_params[:'started_at__gt'] = opts[:'started_at__gt'] if !opts[:'started_at__gt'].nil?
  query_params[:'started_at__gte'] = opts[:'started_at__gte'] if !opts[:'started_at__gte'].nil?
  query_params[:'started_at__lt'] = opts[:'started_at__lt'] if !opts[:'started_at__lt'].nil?
  query_params[:'started_at__lte'] = opts[:'started_at__lte'] if !opts[:'started_at__lte'].nil?
  query_params[:'started_at__range'] = @api_client.build_collection_param(opts[:'started_at__range'], :csv) if !opts[:'started_at__range'].nil?
  query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil?
  query_params[:'state__in'] = @api_client.build_collection_param(opts[:'state__in'], :csv) if !opts[:'state__in'].nil?
  query_params[:'task_group'] = opts[:'task_group'] if !opts[:'task_group'].nil?
  query_params[:'worker'] = opts[:'worker'] if !opts[:'worker'].nil?
  query_params[:'worker__in'] = @api_client.build_collection_param(opts[:'worker__in'], :csv) if !opts[:'worker__in'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'PaginatedTaskResponseList' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_my_permissions(task_href, opts = {}) ⇒ MyPermissionsResponse

List permissions available to the current user on this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



446
447
448
449
# File 'lib/pulpcore_client/api/tasks_api.rb', line 446

def tasks_my_permissions(task_href, opts = {})
  data, _status_code, _headers = tasks_my_permissions_with_http_info(task_href, opts)
  data
end

#tasks_my_permissions_with_http_info(task_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>

List permissions available to the current user on this object.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(MyPermissionsResponse, Integer, Hash)>)

    MyPermissionsResponse data, response status code and response headers



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/pulpcore_client/api/tasks_api.rb', line 457

def tasks_my_permissions_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_my_permissions ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_my_permissions"
  end
  # resource path
  local_var_path = '{task_href}my_permissions/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'MyPermissionsResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_purge(purge, opts = {}) ⇒ AsyncOperationResponse

Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp (tech-preview, may change in the future).

Parameters:

  • purge (Purge)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



511
512
513
514
# File 'lib/pulpcore_client/api/tasks_api.rb', line 511

def tasks_purge(purge, opts = {})
  data, _status_code, _headers = tasks_purge_with_http_info(purge, opts)
  data
end

#tasks_purge_with_http_info(purge, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Purge Completed Tasks Trigger an asynchronous task that deletes completed tasks that finished prior to a specified timestamp (tech-preview, may change in the future).

Parameters:

  • purge (Purge)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AsyncOperationResponse, Integer, Hash)>)

    AsyncOperationResponse data, response status code and response headers



521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/pulpcore_client/api/tasks_api.rb', line 521

def tasks_purge_with_http_info(purge, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_purge ...'
  end
  # verify the required parameter 'purge' is set
  if @api_client.config.client_side_validation && purge.nil?
    fail ArgumentError, "Missing the required parameter 'purge' when calling TasksApi.tasks_purge"
  end
  # resource path
  local_var_path = '/pulp/api/v3/tasks/purge/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(purge) 

  # return_type
  return_type = opts[:return_type] || 'AsyncOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_purge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_read(task_href, opts = {}) ⇒ TaskResponse

Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. \“Normal\” Django Models and Master/Detail models are supported by the register_with method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to ‘pk’ endpoint_name (str): The name of the final path segment that should identify the ViewSet’s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the \“parent_prefix\” of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object’s identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



577
578
579
580
# File 'lib/pulpcore_client/api/tasks_api.rb', line 577

def tasks_read(task_href, opts = {})
  data, _status_code, _headers = tasks_read_with_http_info(task_href, opts)
  data
end

#tasks_read_with_http_info(task_href, opts = {}) ⇒ Array<(TaskResponse, Integer, Hash)>

Inspect a task A customized named ModelViewSet that knows how to register itself with the Pulp API router. This viewset is discoverable by its name. \&quot;Normal\&quot; Django Models and Master/Detail models are supported by the &#x60;&#x60;register_with&#x60;&#x60; method. Attributes: lookup_field (str): The name of the field by which an object should be looked up, in addition to any parent lookups if this ViewSet is nested. Defaults to &#39;pk&#39; endpoint_name (str): The name of the final path segment that should identify the ViewSet&#39;s collection endpoint. nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must correspond to the \&quot;parent_prefix\&quot; of a router with rest_framework_nested.NestedMixin. None indicates this ViewSet should not be nested. parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs to django model filter expressions that can be used with the corresponding value from self.kwargs, used only by a nested ViewSet to filter based on the parent object&#39;s identity. schema (DefaultSchema): The schema class to use by default in a viewset.

Parameters:

  • task_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:

  • (Array<(TaskResponse, Integer, Hash)>)

    TaskResponse data, response status code and response headers



589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
# File 'lib/pulpcore_client/api/tasks_api.rb', line 589

def tasks_read_with_http_info(task_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_read ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_read"
  end
  # resource path
  local_var_path = '{task_href}'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TaskResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_remove_role(task_href, nested_role, opts = {}) ⇒ NestedRoleResponse

Remove a role for this object from users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



643
644
645
646
# File 'lib/pulpcore_client/api/tasks_api.rb', line 643

def tasks_remove_role(task_href, nested_role, opts = {})
  data, _status_code, _headers = tasks_remove_role_with_http_info(task_href, nested_role, opts)
  data
end

#tasks_remove_role_with_http_info(task_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>

Remove a role for this object from users/groups.

Parameters:

  • task_href (String)
  • nested_role (NestedRole)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(NestedRoleResponse, Integer, Hash)>)

    NestedRoleResponse data, response status code and response headers



653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
# File 'lib/pulpcore_client/api/tasks_api.rb', line 653

def tasks_remove_role_with_http_info(task_href, nested_role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_remove_role ...'
  end
  # verify the required parameter 'task_href' is set
  if @api_client.config.client_side_validation && task_href.nil?
    fail ArgumentError, "Missing the required parameter 'task_href' when calling TasksApi.tasks_remove_role"
  end
  # verify the required parameter 'nested_role' is set
  if @api_client.config.client_side_validation && nested_role.nil?
    fail ArgumentError, "Missing the required parameter 'nested_role' when calling TasksApi.tasks_remove_role"
  end
  # resource path
  local_var_path = '{task_href}remove_role/'.sub('{' + 'task_href' + '}', CGI.escape(task_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(nested_role) 

  # return_type
  return_type = opts[:return_type] || 'NestedRoleResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end