Class: PulpcoreClient::UpstreamPulpResponse
- Inherits:
-
Object
- Object
- PulpcoreClient::UpstreamPulpResponse
- Defined in:
- lib/pulpcore_client/models/upstream_pulp_response.rb
Overview
Serializer for a Server.
Instance Attribute Summary collapse
-
#api_root ⇒ Object
The API root.
-
#base_url ⇒ Object
The transport, hostname, and an optional port of the Pulp server.
-
#ca_cert ⇒ Object
A PEM encoded CA certificate used to validate the server certificate presented by the remote server.
-
#client_cert ⇒ Object
A PEM encoded client certificate used for authentication.
-
#domain ⇒ Object
The domain of the Pulp server if enabled.
-
#hidden_fields ⇒ Object
List of hidden (write only) fields.
-
#last_replication ⇒ Object
Timestamp of the last replication that occurred.
-
#name ⇒ Object
A unique name for this Pulp server.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_last_updated ⇒ Object
Timestamp of the most recent update of the remote.
-
#q_select ⇒ Object
Filter distributions on the upstream Pulp using complex filtering.
-
#tls_validation ⇒ Object
If True, TLS peer validation must be performed.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpstreamPulpResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpstreamPulpResponse
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpcoreClient::UpstreamPulpResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpcoreClient::UpstreamPulpResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'base_url') self.base_url = attributes[:'base_url'] else self.base_url = nil end if attributes.key?(:'api_root') self.api_root = attributes[:'api_root'] else self.api_root = nil end if attributes.key?(:'domain') self.domain = attributes[:'domain'] end if attributes.key?(:'ca_cert') self.ca_cert = attributes[:'ca_cert'] end if attributes.key?(:'client_cert') self.client_cert = attributes[:'client_cert'] end if attributes.key?(:'tls_validation') self.tls_validation = attributes[:'tls_validation'] end if attributes.key?(:'hidden_fields') if (value = attributes[:'hidden_fields']).is_a?(Array) self.hidden_fields = value end end if attributes.key?(:'q_select') self.q_select = attributes[:'q_select'] end if attributes.key?(:'last_replication') self.last_replication = attributes[:'last_replication'] end end |
Instance Attribute Details
#api_root ⇒ Object
The API root. Defaults to ‘/pulp/’.
37 38 39 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 37 def api_root @api_root end |
#base_url ⇒ Object
The transport, hostname, and an optional port of the Pulp server. e.g. example.com
34 35 36 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 34 def base_url @base_url end |
#ca_cert ⇒ Object
A PEM encoded CA certificate used to validate the server certificate presented by the remote server.
43 44 45 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 43 def ca_cert @ca_cert end |
#client_cert ⇒ Object
A PEM encoded client certificate used for authentication.
46 47 48 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 46 def client_cert @client_cert end |
#domain ⇒ Object
The domain of the Pulp server if enabled.
40 41 42 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 40 def domain @domain end |
#hidden_fields ⇒ Object
List of hidden (write only) fields
52 53 54 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 52 def hidden_fields @hidden_fields end |
#last_replication ⇒ Object
Timestamp of the last replication that occurred. Equals to ‘null’ if no replication task has been executed.
58 59 60 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 58 def last_replication @last_replication end |
#name ⇒ Object
A unique name for this Pulp server.
31 32 33 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 31 def name @name end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 22 def prn @prn end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_last_updated ⇒ Object
Timestamp of the most recent update of the remote.
28 29 30 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#q_select ⇒ Object
Filter distributions on the upstream Pulp using complex filtering. E.g. pulp_label_select="foo" OR pulp_label_select="key=val"
55 56 57 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 55 def q_select @q_select end |
#tls_validation ⇒ Object
If True, TLS peer validation must be performed.
49 50 51 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 49 def tls_validation @tls_validation end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 285 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpcoreClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 61 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'name' => :'name', :'base_url' => :'base_url', :'api_root' => :'api_root', :'domain' => :'domain', :'ca_cert' => :'ca_cert', :'client_cert' => :'client_cert', :'tls_validation' => :'tls_validation', :'hidden_fields' => :'hidden_fields', :'q_select' => :'q_select', :'last_replication' => :'last_replication' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 111 112 113 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 106 def self.openapi_nullable Set.new([ :'domain', :'ca_cert', :'client_cert', :'q_select', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 86 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'name' => :'String', :'base_url' => :'String', :'api_root' => :'String', :'domain' => :'String', :'ca_cert' => :'String', :'client_cert' => :'String', :'tls_validation' => :'Boolean', :'hidden_fields' => :'Array<GenericRemoteResponseHiddenFieldsInner>', :'q_select' => :'String', :'last_replication' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && name == o.name && base_url == o.base_url && api_root == o.api_root && domain == o.domain && ca_cert == o.ca_cert && client_cert == o.client_cert && tls_validation == o.tls_validation && hidden_fields == o.hidden_fields && q_select == o.q_select && last_replication == o.last_replication end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 356 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 254 def hash [pulp_href, prn, pulp_created, pulp_last_updated, name, base_url, api_root, domain, ca_cert, client_cert, tls_validation, hidden_fields, q_select, last_replication].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 197 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @base_url.nil? invalid_properties.push('invalid value for "base_url", base_url cannot be nil.') end if @api_root.nil? invalid_properties.push('invalid value for "api_root", api_root cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
332 333 334 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 332 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
326 327 328 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 326 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 |
# File 'lib/pulpcore_client/models/upstream_pulp_response.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @base_url.nil? return false if @api_root.nil? true end |